<?php
/**************************************************************************
 * $Id: StudIPortDownload.php 4534 2011-01-13 14:47:44Z weyer $
 *
 * Copyright (C) 2008, 2009, 2010; Hamburg University of Technology
 *
 * > TECHNICAL REALIZATION
 *   Christian Renner <christian.renner@tu-harburg.de>
 *   Leo Krueger
 *   Sigurd Spieckermann
 *
 * > CONCEPT
 *   Peter Baasch
 *   Detlev Bieler
 *   Thomas Czerwionka
 *   Thomas Hapke
 *   Soenke Knutzen
 *   Corinna Peters
 *   Christian Renner
 *   Volker Turau
 *   Olav Wilde
 *
 **************************************************************************
 * This file is part of "StudIPort 2.0 ePortfolio".
 *
 * "StudIPort 2.0 ePortfolio" is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * "StudIPort 2.0 ePortfolio" is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with "StudIPort 2.0 ePortfolio".
 * If not, see <http://www.gnu.org/licenses/>.
 *
 *************************************************************************/

require_once dirname(__file__)."/../../../../lib/bootstrap.php";

require_once('config/StudIPort.config.php');

require_once('StudIPortAuth.system.php');
require_once('StudIPortDB.system.php');
require_once('StudIPortUser.system.php');
require_once('StudIPortTools.lib.php');

if (!class_exists('PclZip')) {
    require_once('ext/pclzip/pclzip.lib.php');
}

// helper function for file renaming
$realFileNames = array();
function zipRenameFile($p_event, &$p_header)
{
	global $realFileNames;
	$p_header['stored_filename'] = $realFileNames[$p_header['stored_filename']];
	return 1;
}

$studiportAuth = new StudIPortAuth();

// check, if file_id has been entered
if (!isset($_REQUEST['file_id']))
	die('Es wurde keine File-ID &uuml;bermittelt.');

if (strpos($_REQUEST['file_id'], ",") === false) // no comma separation => single file download
{
	$numFiles = 1;

	$fileIdString = $_REQUEST['file_id'];
}
else // multiple files download
{
	$fileIds  = explode(",", $_REQUEST['file_id']);

	$numFiles = count($fileIds);

	// check, if values are of type integer
	if (!array_isNumeric($fileIds))
		die('Die File-ID enthaelt ungltige Zeichen.');

	$fileIdString = implode(",", $fileIds);
}

// get data from database
$sql = new StudIPortDB();

// check permissions
// TODO replace this with accurate, system-independant auth checking
if ($studiportAuth->isLoggedIn()) {
	$user_id = StudIPortUser::theUser()->getUserId();
	$sql->queryf("SELECT DISTINCT file.int_filename, file.type_id, file.filename, file.mimetype, file.file_id
				  FROM            studiport_file        AS file
				  LEFT JOIN       studiport_view_files  AS view_files  USING(file_id)
				  LEFT JOIN       studiport_view_access AS view_access USING(view_id)
				  WHERE           file.file_id IN(%s)
				  AND             (file.user_id = '%s' OR view_access.user_id = '%s')",
				  $fileIdString, $user_id, $user_id);
} elseif (isset($_SESSION['StudIPortExtAcc']['access_code'])) {
	$sql->queryf(
		"SELECT DISTINCT file.int_filename, file.type_id, file.filename, file.mimetype, file.file_id" .
		"  FROM        studiport_file        AS file" .
		"  LEFT JOIN   studiport_view_files  AS view_files  USING(file_id)" .
		"  LEFT JOIN   studiport_view        AS view        USING(view_id)" .
		"  WHERE       file.file_id IN(%s)" .
		"    AND       view.public = 'Y'" .
		"    AND       view.access_code = '%s'" .
		"    AND (     NOT view.expires" .
		"      OR      view.expires >= CURDATE())",
		$fileIdString, $_SESSION['StudIPortExtAcc']['access_code']);
} else {
	die('Sie sind weder eingeloggt noch haben Sie einen Zugangscode fr den externen Zugang eingegeben!');
}

// no access rights, if number of results is zero
if ($sql->affected_rows() != $numFiles)
	die('Sie haben keine Berechtigung zum Download der Datei(en) oder die angegebene(n) File-ID(s) existieren nicht.');

// collect files and generate download file
if ($numFiles == 1) // download single file
{
	$sql->next_record();

	if ($sql->f("type_id") == STUDIPORT_FILETYPE_URL) {
		//header("HTTP/1.1 201 Created");
		$url = $sql->f("filename");
		if (is_null(parse_url($url, PHP_URL_SCHEME))) {
	                $url = 'http://' . $url;
        	}
		header("Location: " . $url);
		exit;
	} else {

		// get path + filename of file with hash name
		$filePath = STUDIPORT_DOWNLOAD_DIR . '/' . $sql->f("int_filename");

		if (! is_file($filePath))
			die('Die angegebene Datei existiert nicht im Upload-Verzeichnis. Bitte Administrator kontaktieren!');

		$mimetype = $sql->f("mimetype");
		$filename = $sql->f("filename");

		$content = file_get_contents($filePath);
	}
}
else // download files package
{
	//$zipTempPath = STUDIPORT_DOWNLOAD_DIR . '/' . $user->id;
	$filename = 'ZIP_Paket.zip';
	$mimetype = 'application/zip';
	$filePath = tempnam('', '');
	$filelist = array();

	// create a temporary zip file with temporary name "userID"
	$zip = new PclZip($filePath);

	// TODO handle links/urls separately
	while($sql->next_record()) {
		// create file list to be zipped
		$realFileNames[$sql->f('int_filename')] = $sql->f('filename');
		$filelist[] = STUDIPORT_DOWNLOAD_DIR . '/' . $sql->f("int_filename");
	}

	// create temp ZIP archive, read binary contents
	if ($zip->create($filelist, PCLZIP_OPT_REMOVE_ALL_PATH, PCLZIP_CB_PRE_ADD, 'zipRenameFile')) {
		$content = file_get_contents($filePath);
	}
}

// everything is fine => set file header, name, ending and mime-type and load file content into this script
header("HTTP/1.1 200 OK");
header("Content-Type: " . $mimetype);
header("Content-Disposition: attachment; filename=\"" . $filename ."\"");

echo $content;
?>
