<?php
/**************************************************************************
 * $Id: StudIPortSystemPlugin.class.php 4578 2011-01-18 11:12:58Z renner $
 *
 * Copyright (C) 2008, 2009, 2010; Hamburg University of Technology
 *
 * > TECHNICAL REALIZATION
 *   Christian Renner <christian.renner@tu-harburg.de>
 *   Leo Krueger
 *   Sigurd Spieckermann
 *
 * > CONCEPT
 *   Peter Baasch
 *   Detlev Bieler
 *   Thomas Czerwionka
 *   Thomas Hapke
 *   Soenke Knutzen
 *   Corinna Peters
 *   Christian Renner
 *   Volker Turau
 *   Olav Wilde
 *
 **************************************************************************
 * This file is part of "StudIPort 2.0 ePortfolio".
 *
 * "StudIPort 2.0 ePortfolio" is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * "StudIPort 2.0 ePortfolio" is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with "StudIPort 2.0 ePortfolio".
 * If not, see <http://www.gnu.org/licenses/>.
 *
 *************************************************************************/


// include some libs
require_once('config/StudIPort.config.php');


require_once('StudIPortDB.system.php');
require_once('StudIPortUser.system.php');
require_once('StudIPortLinkEngine.system.php');
require_once('StudIPortUtilities.system.php');

require_once('StudIPort.core.php');

require_once('StudIPortAccess.lib.php');

require_once('ext/flexi-templates/flexi.php');

// include some studip libs
require_once('lib/include/reiter.inc.php');

/** @class StudIPortSystemPlugin
 * @extends AbstractStudIPSystemPlugin
 * @brief Pluginclass, called by studip
 */
class StudIPortSystemPlugin extends AbstractStudIPSystemPlugin
{
	protected  $factory;	// a template factory

	// the navigation structure
	private $tabs = array(
		"overview"    => array("dispName" => "bersicht",          "inCat" => ""),
		"news"        => array("dispName" => "Neuigkeiten",        "inCat" => "overview"),
		"myportfolio" => array("dispName" => "Mein ePortfolio",    "inCat" => ""),
		"matrix"      => array("dispName" => "Matrix",             "inCat" => "myportfolio"),
		"artefacts"   => array("dispName" => "Dateien",            "inCat" => "myportfolio"),
		"views"       => array("dispName" => "Ansichten",          "inCat" => "myportfolio"),
		"others"      => array("dispName" => "Andere ePortfolios", "inCat" => ""),
		"help"        => array("dispName" => "Hilfe",              "inCat" => ""),
		"contact"     => array("dispName" => "Kontakt",            "inCat" => "help"),
		"version"     => array("dispName" => "Versionsinfos",      "inCat" => "help")
	);

	/**
	 * @param void
	 */
	public function __construct () {

		parent::AbstractStudIPSystemPlugin();

		// initialize navigation
		//pre 2.0
		if (!class_exists('PageLayout')) {
		    $nav = new PluginNavigation(_("ePortfolio"));

		    // create subnavi
		    /* does not work in 1.10 !
		     foreach ($this->tabs as $tab => &$data) {
		     if (empty($data["inCat"])) {
		     $navEntry =& new PluginNavigation();
		     $navEntry->setDisplayname($data['dispName']);
		     $navEntry->addLinkParam('action', $tab);
		     $navEntry->setActive(true);
		     $nav->addSubmenu($navEntry);
		     }
		     }
		     */

		    $this->setNavigation($nav);
		    $nav->setActive(false);  // fix in order to let navi appear in >=1.11


		    // set our icon depending on userHasNews()
		    $hasNews = $this->userHasNews();
		    $nav->setIcon("/". STUDIPORT_IMG_FOLDER ."/header_studiport". ($hasNews ? "_red" : "") .".png");
		    $this->setPluginiconname("/". STUDIPORT_IMG_FOLDER ."/header_studiport". ($hasNews ? "_red" : "") .".png");
		} else {
		    $nav = new Navigation(_("ePortfolio"), PluginEngine::getURL($this, array(), "show"));
		    $nav->setImage(
		    $this->getPluginURL()."/".STUDIPORT_IMG_FOLDER."/header_studiport_2_0.png",
		    array('class' => $this->userHasNews() ? "new" : "")
		    );
		    Navigation::addItem("/studiport", $nav);
		}
	}

	/**
	 * @param void
	 */
	public function __destruct () {
	}

	/** is executed when a pluginpage is shown
	 * inserts additionally required CSS and JavaScript
	 * @param void
	 */
	public function initialize() {
		global $HELP_KEYWORD, $EXTERNAL_HELP_LOCATIONID;
		$HELP_KEYWORD="Basis.ePortfolio";
		$EXTERNAL_HELP_LOCATIONID = tuhh;

		// FIXME localization and foreign language support ....
		setlocale(LC_ALL, 'de_DE');
		new StudIPortDB("SET lc_time_names = 'de_DE'");

		// set additional headers
		global $_include_additional_header;

		// include css
		global $studiport_css_header;
		$_include_additional_header .= $studiport_css_header;

		// include js
		global $studiport_js_header;
		$_include_additional_header .= $studiport_js_header;
	}

	/** returns the name
	 * @param void
	 */
	public function getPluginname() {
		return _(STUDIPORT_PLUGIN_NAME);
	}

	/** shows the homepage
	 * @param void
	 */
	public function actionshow($subnavi) {
		$this->actionoverview($subnavi);
	}

	/**	shows the overview
	 * @param void
	 */
	public function actionoverview($subnavi) {
		// set the root subpage
		if (empty($subnavi)) {
			$subnavi = "news";
		}

		$this->show("overview", $subnavi);
	}

	/**	shows my portfolio
	 * @param void
	 */
	public function actionmyportfolio($subnavi) {
		// set the root subpage
		if (empty($subnavi)) {
			$subnavi = "matrix";
		}

		$this->show("myportfolio", $subnavi);
	}

	/**	shows other portfolios
	 * @param void
	 */
	public function actionothers($subnavi) {
		// set the root subpage
		if (empty($subnavi)) {
			$subnavi = "others";
		}

		$this->show("others", $subnavi);
	}

	/**	shows the help
	 * @param void
	 */
	public function actionhelp($subnavi) {
		// set the root subpage
		if (empty($subnavi)) {
			$subnavi = "contact";
		}

		$this->show("help", $subnavi);
	}

	/** generates the tab structure to display
	 * @param active plugin page
	 */
	private function displayTabs($active) {
		$structure = array();

		foreach ($this->tabs as $tab => &$data) {
			if (empty($data["inCat"])) {
				$link = PluginEngine::getLink($this, NULL, $tab);
		 	} else {
				$link = PluginEngine::getLink($this, array("plugin_subnavi_params" => $tab), $data["inCat"]);
		 	}

			$structure[$tab] = array(
				"topKat" => $data["inCat"],
				"name"   => _($data["dispName"]),
				"link"   => $link,
				"active" => ($tab == $active)
			);
		}

		$reiter = new reiter;
		$reiter->create($structure, $active);
	}

	/** shows the pluginpages
	 * @param action the parent page to show
	 * @param subnavi the subpage to show
	 */
	public function show($action, $subnavi = NULL) {
	    // create a template factory
		$this->factory = new Flexi_TemplateFactory(STUDIPORT_TEMPLATES);
		$template = $this->factory->open("empty.php");
		$template->set_layout("StudIPortStudIP.php");

		// if subnavi isn't set, take action instead
		$this->displayTabs(empty($subnavi) ? $action : $subnavi);

		switch($subnavi) {
		case 'contact':
			// hier sollte vielleicht noch was hin
			$t = $this->factory->open("StudIPortContact.page.php");
			$template->set_attribute('StudIPortContent', $t->render());
			break;

		case 'version':
			require_once("Version.class.php");
			$v = new Version();
			$template->set_attribute('StudIPortContent', $v->render());
			break;

		default:
			StudIPort::getInstance()->render($subnavi, $this->factory, $template);
			break;
		}

		echo $template->render();
	}

	/** checks if user has news
	 * @param void
	 */
	private function userHasNews() {
		$sql = new StudIPortDB();

		// TODO remove this (but change implementation of overview.lib before)
		global $studiport_nothing_new;
		$studiport_nothing_new = true;

		// any new or edited views?
		$sql->queryf("SELECT view_id " .
				"FROM studiport_view_access access " .
				"LEFT JOIN studiport_view view USING(view_id) " .
				"WHERE access.user_id = '%s' " .
				"AND (NOT view.expires OR CURDATE() <= view.expires) " .
				"AND (viewed = 'N' OR (viewed = 'Y' AND access.accesstime < view.edited))" .
				"LIMIT 0,1", StudIPortUser::theUser()->getUserId());

		if ($sql->num_rows() != 0) {
			$studiport_nothing_new = false;
			return true;
		}

		// new responses?
		$sql->queryf(
			"SELECT response_id " .
			"FROM studiport_feedback_response r " .
			"LEFT JOIN studiport_feedback_question USING (question_id) " .
			"LEFT JOIN studiport_view view USING (view_id) " .
			"WHERE view.user_id = '%s' " .
			"  AND viewed != 'Y' " .
			"  AND DATEDIFF(now(), r.created) BETWEEN 0 AND %d " .
		"LIMIT 0,1", StudIPortUser::theUser()->getUserId(), STUDIPORT_DAYS_NEW);

		if ($sql->num_rows() != 0) {
			$studiport_nothing_new = false;
			return true;
		}
		return false;
	}
}
