<?php
/**************************************************************************
 * $Id: matrix.php 4566 2011-01-17 13:13:16Z weyer $
 *
 * Copyright (C) 2008, 2009, 2010; Hamburg University of Technology
 *
 * > TECHNICAL REALIZATION
 *   Christian Renner <christian.renner@tu-harburg.de>
 *   Leo Krueger
 *   Sigurd Spieckermann
 *
 * > CONCEPT
 *   Peter Baasch
 *   Detlev Bieler
 *   Thomas Czerwionka
 *   Thomas Hapke
 *   Soenke Knutzen
 *   Corinna Peters
 *   Christian Renner
 *   Volker Turau
 *   Olav Wilde
 *
 **************************************************************************
 * This file is part of "StudIPort 2.0 ePortfolio".
 *
 * "StudIPort 2.0 ePortfolio" is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * "StudIPort 2.0 ePortfolio" is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with "StudIPort 2.0 ePortfolio".
 * If not, see <http://www.gnu.org/licenses/>.
 *
 *************************************************************************/

require_once('StudIPortFileTools.lib.php');
require_once('StudIPortUploadTools.lib.php');
require_once('ext/flexi-templates/flexi.php');
require_once('StudIPortDB.system.php');

// TODO TODO TODO
// do we have *any* input validation in here, i.e., can files be dropped by others
// or anything alike?

/** shows or hides rows/cols
 */
function matrixShowHidePart() {
	$res = array(
		"success" => false);

	// check if everything is provided
	if (!isset($_REQUEST["partId"]) || !isset($_REQUEST['isRow']) || !isset($_REQUEST['hide'])) {
		setErrorMsg($res, "Unvollständige Anfrage.");
		return $res;
	}

	// get database connection
	$sql = new StudIPortDB();

	// clean up
	$isRow  = intval($_REQUEST['isRow']);
	$hide   = intval($_REQUEST["hide"]);
	$partId = intval($_REQUEST["partId"]);

	if ($isRow) {
		$mode = "comp";
	} else {
		$mode = "exp";
	}

	// hide
	if ($hide) {
		// mark column as hidden for this user
		$sql->queryf("INSERT INTO studiport_matrix_%s_hide (%s_id, user_id)
		             VALUES ('%s','%s')", $mode, $mode, $partId, StudIPortUser::theUser()->getUserId());

		$success = $sql->affected_rows();

		// delete all files associated with this row/column
		$sql->queryf("DELETE FROM studiport_file_assoc WHERE %s_id = '%s' AND file_id IN (SELECT file_id FROM studiport_file WHERE user_id='%s')",
					$mode, $partId, StudIPortUser::theUser()->getUserId());

	// show
	} else {
		// remove hidden-state for this user
		$sql->queryf("DELETE FROM studiport_matrix_%s_hide WHERE %s_id='%s' AND user_id='%s'", $mode, $mode, $partId, StudIPortUser::theUser()->getUserId());

		$success = $sql->affected_rows();
	}

	// check result
	if (!$success) {
		setErrorMsg($res, "Datenbankoperation fehlgeschlagen.");
		return $res;
	}

	$res['success'] = true;
	return $res;
}

/** removes a file from studiport
 */
function matrixRemoveFile() {
	$res = array(
		"success" => false,
		"lowPrioSuccess" => false,
		"usage" => null,
		"htmlContentList" => "",
		"htmlContentOverview" => "");

	// sanitize file key and check
	$fileKey = intval($_REQUEST['fileK']);
	if (empty($fileKey)) {
		setErrorMsg($res, "Keine Datei gewählt");
		return $res;
	}

	// obtain file association *BEFORE* deleting it
	$keys = fileGetAssoc($fileKey);
	if (empty($keys)) {
		setErrorMsg($res, "Kann Dateizuordnung nicht lesen");
		return $res;
	}

	// try to delete file
	if (fileDelete($fileKey)) {
		$res["success"] = true;
	} else {
		setErrorMsg($res, "Konnte Datei nicht löschen.");
		return $res;
	}

	// get updated matrix information
	if ($keys) {  // if file was not associated, don't reload matrix data
		$resExt_1 = helperGetCellList($keys["comp_id"], $keys["exp_id"], $keys["type_id"]);
		$resExt_2 = helperGetCellOverview($keys["comp_id"], $keys["exp_id"]);
		// prepare result
		if ($resExt_1["success"] && $resExt_2["success"]) {
			$res["lowPrioSuccess"] 	    = true;
			$res["htmlContentList"]     = StudIPortDB::convertFromDB($resExt_1["htmlContent"]);
			$res["num"]                 = StudIPortDB::convertFromDB($resExt_1["num"]);
			$res["htmlContentOverview"] = StudIPortDB::convertFromDB($resExt_2["htmlContent"]);
		} else {
			addWarning($res, $resExt_1["errorMsg"]);
			addWarning($res, $resExt_2["errorMsg"]);
		}
	}

	// update user quota (for file upload dialog)
	$res["usage"] = uploadGetUsageStat(StudIPortUser::theUser()->getUserId());

	return $res;
}

/** allocs a file to comp and exp
 */
function matrixAllocFile() {
	$res = array(
		"success" => false,
		"lowPrioSuccess" => false,
		"htmlContent" => "");

	if(fileAssoc($_REQUEST['fileK'], $_REQUEST['compK'], $_REQUEST['expK'])) {
		$res["success"] = true;
	} else {
		setErrorMsg($res, "Konnte Datei nicht zuordnen.");
		return $res;
	}

	$resExt = helperGetCellOverview($_REQUEST['compK'], $_REQUEST['expK']);
	$resExt_2 = filesGetNoAssocList();
	// prepare result
	if ($resExt["success"]) {
		$res["lowPrioSuccess"] 	= true;
		$res["htmlContent"] 	= StudIPortDB::convertFromDB($resExt["htmlContent"]);
		$res["htmlContentNoAssoc"]  = StudIPortDB::convertFromDB($resExt_2["htmlContent"]);
		$res["numNoAssoc"]          = $resExt_2["number"];
	}


	return $res;
}

/** releases a file from its allocation
 */
function matrixReleaseFile() {
	$res = array(
		"success" => false,
		"lowPrioSuccess" => false,
		"htmlContentList" => "",
		"htmlContentOverview" => "",
		"htmlContentNoAssoc" => "");

	// get current assoc, before it is deleted
	$keys = fileGetAssoc($_REQUEST['fileK']);

	// and then delete the assoc
	if (fileRelease($_REQUEST['fileK'])) {
		$res["success"] = true;
	} else {
		setErrorMsg($res, "Konnte nicht lösen.");
		return $res;
	}

	$resExt_1 = helperGetCellList($keys["comp_id"], $keys["exp_id"], $keys["type_id"]);
	$resExt_2 = helperGetCellOverview($keys["comp_id"], $keys["exp_id"]);
	$resExt_3 = filesGetNoAssocList();

	// prepare result
	if($resExt_1["success"] && $resExt_2["success"]) {
		$res["lowPrioSuccess"]      = true;
		$res["htmlContentList"]     = StudIPortDB::convertFromDB($resExt_1["htmlContent"]);
		$res["num"]                 = StudIPortDB::convertFromDB($resExt_1["num"]);
		$res["htmlContentOverview"] = StudIPortDB::convertFromDB($resExt_2["htmlContent"]);
		$res["htmlContentNoAssoc"]  = StudIPortDB::convertFromDB($resExt_3["htmlContent"]);
		$res["numNoAssoc"]          = $resExt_3["number"];
	} else {
		addWarning($res, $resExt_1["errorMsg"]);
		addWarning($res, $resExt_2["errorMsg"]);
		addWarning($res, $resExt_3["errorMsg"]);
	}

	return $res;
}

/** gets the entries for the filelist-box
 */
function matrixGetCell() {
	$res = array(
		"success" => false,
		"htmlContent" => "");

	$resExt = helperGetCellList($_REQUEST['compK'], $_REQUEST['expK'], $_REQUEST['typeK']);

	// prepare result
	if($resExt["success"]) {
		$res["success"]     = true;
		$res["htmlContent"] = StudIPortDB::convertFromDB($resExt["htmlContent"]);
	}

	return $res;
}

/** saves a comment
 */
function matrixCommentSave() {
	// prepare result
	$res = array(
		"success" => false,
		"text_int" => "",
		"text_ext" => "",
		"picture" => "no"
	);

	// check if parameters are valid
	// TODO we should use an external function here 
	// to check if expKey and compKey are valid
	if(!(is_numeric($_REQUEST["compKey"]) && is_numeric($_REQUEST["expKey"]))) {
		setErrorMsg($res, "Ungueltige Anfrage.");
		return $res;
	}

	// get database connection
	$sql = new StudIPortDB();

	// if the comment is empty, simply remove the corresponding entry from the table!
	// otherwise, we'll trash up the table!
	if (strlen($_REQUEST["text_int"]) == 0 && strlen($_REQUEST["text_ext"]) == 0) {
		$sql->queryf(
			"DELETE FROM studiport_matrix_cell_descr ".
			"WHERE comp_id = %u ".
			"  AND exp_id = %u ".
			" AND user_id = '%s'", $_REQUEST["compKey"], $_REQUEST["expKey"], StudIPortUser::theUser()->getUserId());
		
		$res["success"] = true;
		
		return $res;
	}
		
	// check if entry exists
	$sql->queryf(
		"SELECT comp_id ".
		"FROM studiport_matrix_cell_descr ".
		"WHERE comp_id = %u ".
		"  AND exp_id = %u ".
		"  AND user_id = '%s' ".
		"LIMIT 0,1", $_REQUEST["compKey"], $_REQUEST["expKey"], StudIPortUser::theUser()->getUserId());
	
	// prepare input
	$text_int = sanitizeInput($_REQUEST["text_int"]);
	$text_ext = sanitizeInput($_REQUEST["text_ext"]);
	$set = new MySQLSetClause();
	$set->set('text_int', $text_int);
	$set->set('text_ext', $text_ext);
	
	// if there is no entry, add one
	if ($sql->num_rows() == 0) {
		$set->set('user_id', StudIPortUser::theUser()->getUserId());
		$set->set('comp_id', $_REQUEST["compKey"], false);
		$set->set('exp_id', $_REQUEST["expKey"], false);
		$set->set('created', "now()", false);
		
		$sql->query("INSERT INTO studiport_matrix_cell_descr SET ". $set->get());
		
		if($sql->affected_rows() == 1) {
			$res["success"] = true;
		}
	// update existing entry
	} else {
		$sql->queryf(
			"UPDATE studiport_matrix_cell_descr SET ". $set->get(true) ." ".
			"WHERE comp_id = %u ".
			"  AND exp_id = %u ".
			"  AND user_id = '%s'",
			$_REQUEST["compKey"], $_REQUEST["expKey"], StudIPortUser::theUser()->getUserId());
		
		$res["success"] = true;
	}

	$res2 = matrixGetCellComment();
	$res["text_int"] = $res2["text_int"];
	$res["text_ext"] = $res2["text_ext"];
	$res["picture"] = $res2["picture"];

	return $res;
}

function matrixGetCellComment() {
	// prepare result
	$res = array(
		"success" => false,
		"text_int" => "",
		"text_ext" => "",
		"picture" => "no"
	);

	// check if parameters are valid
	// TODO we should use an external function here 
	// to check if expKey and compKey are valid
	if(!(is_numeric($_REQUEST["compKey"]) && is_numeric($_REQUEST["expKey"]))) {
		setErrorMsg($res, "Ungueltige Anfrage.");
		
		return $res;
	}

	// get database connection
	$sql = new StudIPortDB();

	// get text
	$sql->queryf(
		"SELECT text_int, text_ext ".
		"FROM studiport_matrix_cell_descr ".
		"WHERE comp_id = %u ".
		"  AND exp_id = %u ".
		"  AND user_id = '%s' ".
		"LIMIT 0,1", $_REQUEST["compKey"], $_REQUEST["expKey"], StudIPortUser::theUser()->getUserId());

	// if there is no entry return
	if ($sql->num_rows() == 0) {
		$res["success"] = true;
		
		return $res;
	}
	
	$sql->next_record();

	// calculate which picture to display
	$pictureIndex = 0;
	
	// add 1 if internal text is set
	if (strlen($sql->f("text_int")) > 0) {
		$pictureIndex += 1;
	}
	
	// add 2 if external text is set
	if (strlen($sql->f("text_ext")) > 0) {
		$pictureIndex += 2;
	}
	
	// kind of an enum
	$pictureNameEnum = array("no", "int", "ext", "yes");
	
	// prepare result data
	$res["picture"] = $pictureNameEnum[$pictureIndex];
	$res["text_int"] = StudIPortDB::convertFromDB($sql->f("text_int"));
	$res["text_ext"] = StudIPortDB::convertFromDB($sql->f("text_ext"));
	
	$res["success"] = true;

	return $res;
}


/** HELPER: returns html of a filelist-box
 * @param comp
 * @param exp
 * @param type
 */
function helperGetCellList($comp, $exp, $type) {
	// prepare output
	$res = array(
		"success" => false,
		"num" => 0,
		"htmlContent" => "");

	if(!(is_numeric($comp) && is_numeric($exp) && is_numeric($type))) {
		setErrorMsg($res, "Ungueltige Anfrage.");
		return $res;
	}

	// get database connection
	$sql = new StudIPortDB();

	// get filetype name
	$sql->queryf(
		"SELECT name ".
		"FROM studiport_file_types ".
		"WHERE type_id = %u", $type);

	$sql->next_record();
	$htmlContent = "<div class=\"boxHeader\">". $sql->f('name') ."</div><ul id='files_a'>";

	// get files
	$sql->queryf(
		'SELECT '.
		'  file_id, '.
		'  title, '.
		'  SUBSTRING(descr_ext, 1, '. STUDIPORT_MATRIX_FILE_DESCR_ABBR_LENGTH .') as descr_ext '.
		'FROM studiport_file file '.
		'  LEFT JOIN studiport_file_types types USING (type_id) '.
		'  LEFT JOIN studiport_file_assoc assoc USING (file_id) '.
		'WHERE file.user_id = \'%s\''.
		'  AND comp_id = %u'.
		'  AND exp_id = %u'.
		'  AND type_id = %u', StudIPortUser::theUser()->getUserId(), $comp, $exp, $type);

	$url = STUDIPORT_IMG_URI;

	while ($sql->next_record()) {
		$link = StudIPortLinkEngine::getLink('artefacts', array('file_id' => $sql->f('file_id')));
		$descr_ext = textConvertNewline(textAbbreviate($sql->f('descr_ext'), STUDIPORT_MATRIX_FILE_DESCR_ABBR_LENGTH));

		$htmlContent .= "<li><div class=\"listTitle\"><a href=\"". $link ."\">". $sql->f('title') ."</a></div><div class=\"listActions\">
						<a href=\"javascript:StudIPort.file.release(". $comp .", ". $exp .", ". $sql->f('file_id') .", ". $type.")\"><img src=\"". $url ."/unlink.png\" title='Zuordnung aufheben' alt=\"Zuordnung aufheben\" width='16' height='16'></a>
						<a href=\"". $link ."\"><img src=\"". $url ."/edit.png\" title=\"bearbeiten\" alt='Datei bearbeiten' /></a>
						<a href=\"javascript:StudIPort.file.remove(". $comp .", ". $exp .", ". $sql->f('file_id') .", ". $type.")\"><img src=\"". $url ."/trash.png\" alt=\"Datei löschen\" title='Datei löschen'></a></div><div class=\"listDescr\">". $descr_ext ."</div>
						</li>";
	}

	$htmlContent .= "</ul>";

	// prepare result
	$res["success"]     = true;
	$res["num"]         = $sql->num_rows();
	$res["htmlContent"] = $htmlContent;

	return $res;
}

/** HELPER: returns html of a tablecell
 * @param comp
 * @param exp
 */
function helperGetCellOverview($comp, $exp) {
	$res = array(
		"success" => false,
		"num" => 0,
		"htmlContent" => "");

	if(!(is_numeric($comp) && is_numeric($exp))) {
		setErrorMsg($res, "Ungueltige Anfrage.");
		return $res;
	}

	// get database connection
	$sql = new StudIPortDB();

	// get files
	$sql->queryf("SELECT type_id, types.name, types.picture, types.descr, COUNT(*) as num
				FROM studiport_file file
				LEFT JOIN studiport_file_types types USING (type_id)
				LEFT JOIN studiport_file_assoc assoc USING (file_id)
				WHERE file.user_id = '%s'
				AND comp_id = %u
				AND exp_id = %u
				GROUP BY type_id", StudIPortUser::theUser()->getUserId(), $comp, $exp);

	$url = STUDIPORT_IMG_URI;

	$htmlContent = '';
	while ($sql->next_record()) {
		$htmlContent .= "<img class='filetype' src=\"". $url ."/". $sql->f('picture') ."\" width=\"16\" height=\"16\" alt=\"". $sql->f('descr') ."\"
						onmouseover=\"StudIPort.matrix.openList('div_hoverBox', this, ". $comp .", ". $exp .", ". $sql->f('type_id') .")\"
						onmouseout=\"StudIPort.box.close()\" /><img src=\"". $url ."/context-indicator.png\" class=\"contextIndicator\" /><span class='sub'>". $sql->f('num') ."</span>\n";
	}

	// prepare result
	$res["success"]     = true;
	$res["num"]         = $sql->num_rows();
	$res["htmlContent"] = $htmlContent;

	return $res;
}

?>
