<?php
/**************************************************************************
 * $Id: $
 *
 * Copyright (C) 2008, 2009, 2010; Hamburg University of Technology
 *
 * > TECHNICAL REALIZATION
 *   Christian Renner <christian.renner@tu-harburg.de>
 *   Leo Krueger
 *   Sigurd Spieckermann
 *
 * > CONCEPT
 *   Peter Baasch
 *   Detlev Bieler
 *   Thomas Czerwionka
 *   Thomas Hapke
 *   Soenke Knutzen
 *   Corinna Peters
 *   Christian Renner
 *   Volker Turau
 *   Olav Wilde
 *
 **************************************************************************
 * This file is part of "StudIPort 2.0 ePortfolio".
 *
 * "StudIPort 2.0 ePortfolio" is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * "StudIPort 2.0 ePortfolio" is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with "StudIPort 2.0 ePortfolio".
 * If not, see <http://www.gnu.org/licenses/>.
 *
 *************************************************************************/

require_once("StudIPortTools.lib.php");
require_once('StudIPortDB.system.php');

/**
 * validate view access
 * 1.) check, if view_id provided
 * 2.) check, if view exists in DB
 * 3.) check, if external code correct
 *
 * @param view_id identifier of the queried view
 * @param access_code access code for view
 * @param res JSON result array, used to write error messages
 *
 * @return true, if all checks succeed; false else
 */
function validateViewExtAccess($view_id, $access_code, &$res) {
	// check, if view_id provided at all
	$view_id = intval($view_id);
	if (empty($view_id)) {
		setErrorMsg($res, "Keine Ansicht gewählt");
		return false;
	}

	// prepare database connection
	$db = new StudIPortDB();

	// check, if user is owner
	$db->queryf("SELECT public, IF(expires,expires<CURDATE(),FALSE) AS expired, access_code FROM studiport_view WHERE view_id='%u'", $view_id);

	// does view exist?
	if ($db->num_rows() == 0) {
		setErrorMsg($res, "Ansicht existiert nicht");
		return false;
	}

	// now check the access code
	$db->next_record();
	if ($db->f('public') != 'Y') {
		setErrorMsg($res, "Ansicht ist nicht oeffentlich");
		return false;
	} else if ($db->f('expired')) {
		setErrorMsg($res, "Ansicht ist nicht mehr zugaenglich");
		return false;
	} else if (! empty($access_code) && $db->f('access_code') === $access_code) {
		return true;
	}

	setErrorMsg($res, "xKeine Berechtigung");
	return false;
}

?>
