<?php
/**************************************************************************
 * $Id: $
 *
 * Copyright (C) 2008, 2009, 2010; Hamburg University of Technology
 *
 * > TECHNICAL REALIZATION
 *   Christian Renner <christian.renner@tu-harburg.de>
 *   Leo Krueger
 *   Sigurd Spieckermann
 *
 * > CONCEPT
 *   Peter Baasch
 *   Detlev Bieler
 *   Thomas Czerwionka
 *   Thomas Hapke
 *   Soenke Knutzen
 *   Corinna Peters
 *   Christian Renner
 *   Volker Turau
 *   Olav Wilde
 *
 **************************************************************************
 * This file is part of "StudIPort 2.0 ePortfolio".
 *
 * "StudIPort 2.0 ePortfolio" is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * "StudIPort 2.0 ePortfolio" is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with "StudIPort 2.0 ePortfolio".
 * If not, see <http://www.gnu.org/licenses/>.
 *
 *************************************************************************/

require_once('StudIPortFiles.class.php');
require_once('StudIPortTools.lib.php');


abstract class StudIPortFileList extends StudIPortFiles
{
	protected $filesChecked;
	protected $rights;        // user or owner#
	protected $checkCallback;
	protected $expNumFiles;   // number of files in exp
	protected $cellDescr;     // number of files in exp

	public function __construct(StudIPortUser &$user) {
		parent::__construct($user);

		$this->filesChecked  = array();
		$this->rights        = STUDIPORT_RIGHTS_ALIEN;  // be restrictive by default
		$this->checkCallback = '';
		$this->expNumFiles   = array();
		$this->cellDescr     = array();
	}

	protected function getCellDescr() {
		// get cell descriptions
		$sql =& $this->sql;
		$sql->queryf("SELECT comp_id, exp_id, text_ext FROM studiport_matrix_cell_descr WHERE user_id='%s'", $this->user->getUserId());
		while ($sql->next_record()) {
			$key = $sql->f('exp_id') . ':' . $sql->f('comp_id');
			//$this->cellDescr[$key] = $sql->f('text_ext'); 
			$this->cellDescr[$key] = textConvertNewline($sql->f('text_ext'));
			if ($sql->f('text_ext')) {
				if (isset($this->expNumComments[$sql->f('exp_id')])) {
					$this->expNumComments[$sql->f('exp_id')]++;
				} else {
					$this->expNumComments[$sql->f('exp_id')] = 1;
				}
			}
		}
	}
	
	public function loadData() {
		$this->getCellDescr();
		parent::loadData();
	}

        // get cols and rows with files attached
        protected function getHeaderData() {
                $sql =& $this->sql;

                // get competence/rows headers
                // NOTE if using this statement, overwrite getHeaderData() in
                /*$sql->queryf("SELECT comp_id as id, title, descr ".
                             "FROM studiport_matrix_comp ".
                             "WHERE comp_id NOT IN ".
                             "  (SELECT comp_id FROM studiport_matrix_comp_hide WHERE user_id = '%s') ".
                             "ORDER BY pos ASC", $this->user->getUserId());*/
                $sql->queryf("SELECT comp_id as id, title, descr ".
                             "FROM studiport_matrix_comp ".
                             "ORDER BY pos ASC");

                $this->comp = array();
                $this->saveSqlData($sql, $this->comp);
                // Add an extra field for none-assoc file
                $this->comp[] = array(
                        'id'    => STUDIPORT_COMP_NONE,
                        'title' => NULL,
                        'descr' => NULL
                );

                // get experience/cols headers
                /*$sql->queryf("SELECT exp.exp_id as id, exp.title, exp.descr ".
                             "FROM studiport_matrix_exp AS exp ".
                             "  LEFT JOIN studiport_file_assoc USING(exp_id) ".
                             "  LEFT JOIN studiport_file USING(file_id) ".
                             "WHERE user_id = '%s' ".
                             "GROUP BY exp_id ".
                             "  HAVING COUNT(file_id) > 0 ".
                             "ORDER BY pos ASC", $this->user->getUserId());*/
                $sql->queryf("SELECT exp_id AS id, title, descr ".
                             "FROM studiport_matrix_exp ".
                             "ORDER BY pos ASC");

                $this->exp = array();
                $this->saveSqlData($sql, $this->exp);
                // Add an extra field for none-assoc files
                $this->exp[] = array(
                        'id'    => STUDIPORT_EXP_NONE,
                        'title' => "Nicht zugeordnete Dateien",
                        'descr' => NULL
                );
        }


        protected function prepareData(&$db) {
                // count number of files per exp
                foreach ($this->exp as &$exp) {
                        $this->numFilesExp[$exp['id']] = 0;
                }

                // assign files
                while ($db->next_record()) {
                        // check where to store filedata
                        if ($db->f('exp_id') != NULL) {
                                $pointer =& $this->data[$db->f('comp_id')][$db->f('exp_id')];
				if (isset($this->expNumFiles[$db->f('exp_id')])) {
                                	$this->expNumFiles[$db->f('exp_id')]++;
				} else {
                                	$this->expNumFiles[$db->f('exp_id')] = 1;
				}
                        } else {
                                $pointer =& $this->data[STUDIPORT_COMP_NONE][STUDIPORT_EXP_NONE];
				if (isset($this->expNumFiles[STUDIPORT_EXP_NONE])) {
	                                $this->expNumFiles[STUDIPORT_EXP_NONE]++;
				} else {
	                                $this->expNumFiles[STUDIPORT_EXP_NONE] = 1;
				}
                        }

			$this->saveSqlData($db, $pointer[$db->f('file_id')]);
                }
        }


        /** @see StudIPortBase::render() */
        public function render(Flexi_TemplateFactory &$factory, $templateFilename) {
                parent::render($factory, $templateFilename);

                $this->template->set_attribute('rows',           $this->comp);
                $this->template->set_attribute('cols',           $this->exp);
                $this->template->set_attribute('cellDescr',      $this->cellDescr);
                $this->template->set_attribute('colNumFiles',    $this->expNumFiles);
		if (empty($this->expNumComments)) {
			$this->expNumComments = 0;
		}
                $this->template->set_attribute('colNumComments', $this->expNumComments);
                $this->template->set_attribute('types',          $this->types);
                $this->template->set_attribute('files',          $this->data);
                $this->template->set_attribute('rights',         $this->rights);
                $this->template->set_attribute('filesChecked',   $this->filesChecked);
                $this->template->set_attribute('checkCallback',  $this->checkCallback);
		$this->template->set_attribute('isExtern',       false);

                return $this->template->render();
        }
}
?>
