<?php
/**************************************************************************
 * $Id: $
 *
 * Copyright (C) 2008, 2009, 2010; Hamburg University of Technology
 *
 * > TECHNICAL REALIZATION
 *   Christian Renner <christian.renner@tu-harburg.de>
 *   Leo Krueger
 *   Sigurd Spieckermann
 *
 * > CONCEPT
 *   Peter Baasch
 *   Detlev Bieler
 *   Thomas Czerwionka
 *   Thomas Hapke
 *   Soenke Knutzen
 *   Corinna Peters
 *   Christian Renner
 *   Volker Turau
 *   Olav Wilde
 *
 **************************************************************************
 * This file is part of "StudIPort 2.0 ePortfolio".
 *
 * "StudIPort 2.0 ePortfolio" is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * "StudIPort 2.0 ePortfolio" is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with "StudIPort 2.0 ePortfolio".
 * If not, see <http://www.gnu.org/licenses/>.
 *
 *************************************************************************/
require_once('StudIPortFileList.class.php');

class StudIPortFileListAlien extends StudIPortFileList
{
	protected $ownerId;

	public function __construct(StudIPortUser &$user, $viewId) {
		parent::__construct($user);
		$this->rights        = STUDIPORT_RIGHTS_ALIEN;
		$this->checkCallback = ''; 
		$this->viewId        = $viewId;
	}


        protected function getCellDescr() {
		// TODO no sufficient error checking
                $sql =& $this->sql;
		$sql->queryf("SELECT user_id FROM studiport_view WHERE view_id='%d'", $this->viewId);
		if ($sql->next_record()) {
			$ownerId = $sql->f('user_id');
	                // get cell descriptions
        	        $sql->queryf("SELECT comp_id, exp_id, text_ext FROM studiport_matrix_cell_descr WHERE user_id='%s'",
				$ownerId);
                	while ($sql->next_record()) {
                        	$key = $sql->f('exp_id') . ':' . $sql->f('comp_id');
	                        $this->cellDescr[$key] = textConvertNewline($sql->f('text_ext'));
				if ($sql->f('text_ext')) {
					if (empty($this->expNumComments[$sql->f('exp_id')])) {
						$this->expNumComments[$sql->f('exp_id')] = 1;
					} else {
						$this->expNumComments[$sql->f('exp_id')]++;
					}
				}
        	        }
		}
        }

	
	/** loads files associated with matrix
	 * @see StudIPortMatrixBase::loadData()
	 * @param void
	 */
	public function loadData() {
		parent::loadData();

		if (empty($this->user) || empty($this->viewId)) {
			// TODO error message
			return;
		}
		
		// get reference to db object for better readability
		$sql =& $this->sql;

		// sanity check (is view visible for me?)
		$sql->queryf("SELECT name, descr, NOT expires OR CURDATE() <= expires AS valid
						FROM studiport_view AS view
						LEFT JOIN studiport_view_access AS access USING (view_id)
						WHERE access.user_id='%s'
						AND view_id='%s'", $this->user->getUserId(), $this->viewId);

		// any result? if none, we don't have access
		if (!$sql->next_record()) {
			echo "no access";
			// TODO error message
			return;
		}

		// is the view valid (i.e., not expired)
		if (!$sql->f('valid')) {
			echo "expired";
			// TODO error message
			return;
		}

		// get view meta data
		$sql->queryf("SELECT view_id
					 FROM studiport_view
					 WHERE view_id='%s'", $this->viewId);
		
		if (!$sql->next_record()) {
			echo "no view data";
			// TODO error message
			return;
		}
		// TODO write meta data!	

		// TODO make sql statement that just collects needed data...
		$sql->queryf(
			  "SELECT file_id, title, comp_id,"
			. "	 exp_id, type_id, UNIX_TIMESTAMP(edited) as edited,"
//			. "	 CHAR_LENGTH(file.descr_ext) > 0 as hasText"
			. "	 descr_ext"
			. "	 FROM studiport_file file"
			. "	 LEFT JOIN studiport_file_assoc USING (file_id)"
			. "	 LEFT JOIN studiport_view_files USING (file_id)"
			. "	 WHERE view_id=%d"
			. "	 ORDER BY comp_id, exp_id, title", $this->viewId);

		$this->prepareData($sql);

		// convert text to html
		if ($this->data) {
			foreach ($this->data as &$row) {
				foreach ($row as &$col) {
					foreach ($col as &$file) {
						$file['descr_ext'] = textConvertNewline($file['descr_ext'], STUDIPORT_FILE_DESCR_ABBR_LENGTH);
					}
				}
			}
		}
		
		$sql->queryf("UPDATE studiport_view_access SET viewed = 'Y', accesstime=now()
			WHERE view_id = %d
			AND user_id = '%s'", $this->viewId, $this->user->getUserId());
	}
}
?>
