<?php
/**************************************************************************
 * $Id: $
 *
 * Copyright (C) 2008, 2009, 2010; Hamburg University of Technology
 *
 * > TECHNICAL REALIZATION
 *   Christian Renner <christian.renner@tu-harburg.de>
 *   Leo Krueger
 *   Sigurd Spieckermann
 *
 * > CONCEPT
 *   Peter Baasch
 *   Detlev Bieler
 *   Thomas Czerwionka
 *   Thomas Hapke
 *   Soenke Knutzen
 *   Corinna Peters
 *   Christian Renner
 *   Volker Turau
 *   Olav Wilde
 *
 **************************************************************************
 * This file is part of "StudIPort 2.0 ePortfolio".
 *
 * "StudIPort 2.0 ePortfolio" is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * "StudIPort 2.0 ePortfolio" is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with "StudIPort 2.0 ePortfolio".
 * If not, see <http://www.gnu.org/licenses/>.
 *
 *************************************************************************/

require_once('StudIPortPage.class.php');
require_once('StudIPortQuestionTools.lib.php');
require_once('StudIPortRequestList.class.php');
require_once('StudIPortResponseList.class.php');


class StudIPortPageQuestionDetails extends StudIPortPage
{
	// member variables
	protected $questionId;   ///> view id
	protected $question;     ///> whole view as obtained from DB
	protected $requests;     ///> access table for this view
	protected $responses;    ///> files of user

	/**
	 * @see StudIPort::__construct
	 * @param user StudIP user object of calling user
	 */
	public function __construct(StudIPortUser &$user, $questionId) {
		parent::__construct($user);
		$this->questionId = intval($questionId);
		$this->question   = null;
		$this->requests   = null;
		$this->responses  = null;
	}

	/**
	 *  @user_id
	 */
	public function loadData() {
		if (!empty($this->view) || empty($this->user)) {
			// TODO print error msg
			return;
		}

                // sanity check to ensure that view belongs to user
                if (! validateQuestionAccess($this->questionId, $this->user->getUserId(), $res, QUESTION_ROLE_OWNER)) {
                        // TODO error message
                        $this->question = null;
                        return;
                }

		// get view from database
		$this->question = questionGetBasics($this->questionId);
		if ($this->question == null) {
			// TODO error message
			return;
		}

		// we've got the view and its basic data, so get into details
		// 1.) get users requested feedback from
		$this->requests = new StudIPortRequestList($this->user, $this->questionId);
		$this->requests->loadData();

		// 2.) get replies belonging to this question
		$this->responses = new StudIPortResponseList($this->user, $this->questionId);
		$this->responses->loadData();
	}

	/**
	*/
	public function render(Flexi_TemplateFactory &$factory, $templateFilename) {
		parent::render($factory, $templateFilename);
		$this->template->set_attribute('data', $this->question);
		$this->template->set_attribute('requests', $this->requests->render($factory, "StudIPortRequestList.part.php"));
		$this->template->set_attribute('showRequests', $this->requests->getNum() == 0 && $this->responses->getNum() == 0);
//                $this->responses->setStyle(STUDIPORT_STYLE_NESTED); // we want a nested file list
                $this->template->set_attribute('responses', $this->responses->render($factory, "StudIPortResponseList.part.php"));
		$this->template->set_attribute('showResponses', $this->responses->getNumNew() > 0);
                return $this->template->render();

	}
}
?>
