<?php
/**************************************************************************
 * $Id: $
 *
 * Copyright (C) 2008, 2009, 2010; Hamburg University of Technology
 *
 * > TECHNICAL REALIZATION
 *   Christian Renner <christian.renner@tu-harburg.de>
 *   Leo Krueger
 *   Sigurd Spieckermann
 *
 * > CONCEPT
 *   Peter Baasch
 *   Detlev Bieler
 *   Thomas Czerwionka
 *   Thomas Hapke
 *   Soenke Knutzen
 *   Corinna Peters
 *   Christian Renner
 *   Volker Turau
 *   Olav Wilde
 *
 **************************************************************************
 * This file is part of "StudIPort 2.0 ePortfolio".
 *
 * "StudIPort 2.0 ePortfolio" is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * "StudIPort 2.0 ePortfolio" is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with "StudIPort 2.0 ePortfolio".
 * If not, see <http://www.gnu.org/licenses/>.
 *
 *************************************************************************/

require_once('StudIPortPage.class.php');
require_once('StudIPortFeedbackList.class.php');
require_once('StudIPortFileListAlien.class.php');
require_once('StudIPortAvatar.system.php');


class StudIPortPageViewAlien extends StudIPortPage
{
	// member variables
	protected $viewId;    ///> view id
	protected $view;      ///> view basics
	protected $files;     ///> files of view
	protected $feedback;  ///> feedback of view (requested from and given by current viewer/user)

	/**
	 * @see StudIPort::__construct
	 * @param user StudIP user object of calling user
	 */
	public function __construct(StudIPortUser &$user, $viewId) {
		parent::__construct($user);
		$this->viewId   = intval($viewId);
		$this->view     = null;
		$this->files    = null;
		$this->feedback = null;
	}

	/**
	 *  @user_id
	 */
	public function loadData() {
		if (!empty($this->view) || empty($this->user)) {
			// TODO print error msg
			return;
		}

		// sanity check to ensure that question belongs to user
                if (! validateViewAccess($this->viewId, $this->user->getUserId(), $res, VIEW_ROLE_ALIEN)) {
                        // TODO error message
                        $this->view = null;
                        return;
                }


		$sql =& $this->sql;

		// get view basics and owner
		global $_fullname_sql;
		$sql->queryf(
			  " SELECT"
			. "   view_id,"
			. "   name,"
			. "   descr,"
			. "   user_id"
			. " FROM studiport_view"
			. " WHERE view_id='%d'",
			$this->viewId);
		$sql->next_record();

		$userData = array();
		if (StudIPortUser::getByUserId($userData, $sql->f('user_id')) != 1) {
			// TODO internal error: user not found
		}
		$this->view = array_merge($sql->get_record(), $userData[0]);
		
		// get files
		$this->files = new StudIPortFileListAlien($this->user, $this->viewId);
		$this->files->loadData();

		// get feedback
		$this->feedback = new StudIPortFeedbackList($this->user, $this->viewId);
		$this->feedback->loadData();
	}

	/**
	*/
	public function render(Flexi_TemplateFactory &$factory, $templateFilename) {
		parent::render($factory, $templateFilename);
		$this->template->set_attribute('view', $this->view);
		$this->files->setStyle(STUDIPORT_STYLE_STANDALONE);
		$this->template->set_attribute('files', $this->files->render($factory, "StudIPortFileList.part.php"));
		$this->template->set_attribute('showFeedback', $this->feedback->getNumRequests() > 0);
		$this->template->set_attribute('feedback', $this->feedback->render($factory, "StudIPortFeedbackList.part.php"));
                return $this->template->render();

	}

        /*
         * @see StudIPortPage::renderInfobox()
         * @param void
         */
        public function renderInfobox(Flexi_TemplateFactory &$factory) {
                // assign attributes
                $template = $factory->open("StudIPortViewAlien.infobox.php");
                $template->set_attribute('view_id', $this->viewId);

                // render
                return $template->render();
        }

}
?>
