<?php
/**************************************************************************
 * $Id: $
 *
 * Copyright (C) 2008, 2009, 2010; Hamburg University of Technology
 *
 * > TECHNICAL REALIZATION
 *   Christian Renner <christian.renner@tu-harburg.de>
 *   Leo Krueger
 *   Sigurd Spieckermann
 *
 * > CONCEPT
 *   Peter Baasch
 *   Detlev Bieler
 *   Thomas Czerwionka
 *   Thomas Hapke
 *   Soenke Knutzen
 *   Corinna Peters
 *   Christian Renner
 *   Volker Turau
 *   Olav Wilde
 *
 **************************************************************************
 * This file is part of "StudIPort 2.0 ePortfolio".
 *
 * "StudIPort 2.0 ePortfolio" is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * "StudIPort 2.0 ePortfolio" is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with "StudIPort 2.0 ePortfolio".
 * If not, see <http://www.gnu.org/licenses/>.
 *
 *************************************************************************/

require_once('StudIPortPage.class.php');
require_once('StudIPortViewTools.lib.php');
require_once('StudIPortFileListOwner.class.php');


abstract class StudIPortPageViewDetailsBase extends StudIPortPage
{
	// member variables
	protected $viewId;   ///> view id
	protected $view;     ///> whole view as obtained from DB
	protected $access;   ///> access table for this view
	protected $files;    ///> files of user

	/**
	 * @see StudIPort::__construct
	 * @param user StudIP user object of calling user
	 */
	public function __construct(StudIPortUser &$user, $viewId) {
		parent::__construct($user);
		$this->viewId = intval($viewId);
		$this->view   = null;
		$this->access = null;
		$this->files  = null;
	}

	/**
	 *  @user_id
	 */
	public function loadData() {
		if (!empty($this->view) || empty($this->user)) {
			// TODO print error msg
			return;
		}

		// sanity check to ensure that view belongs to user
		$res = array();
		if (! validateViewAccess($this->viewId, $this->user->getUserId(), $res, VIEW_ROLE_OWNER)) {
			// TODO error message
			$this->view = null;
echo $res['errorMsg'];
			return;
		}

		// get view from database
		$this->view = viewGetBasics($this->viewId);
		if ($this->view == null) {
			// TODO error message
			return;
		}


		// we've got the view and its basic data, so get into details
		// 1.) get users with access to this view
		$this->access = getStudIPortViewAccessList($this->viewId);

		// 2.) get files belonging to this view
		$this->files = new StudIPortFileListOwner($this->user, $this->viewId);
		$this->files->setStyle(STUDIPORT_STYLE_NESTED);
		$this->files->loadData();
	}

	/**
	* @param id file id from studiport_files table
	*/
	public function render(Flexi_TemplateFactory &$factory, $templateFilename) {
		parent::render($factory, $templateFilename);
	}
}
?>
