<?php
/**************************************************************************
 * $Id: $
 *
 * Copyright (C) 2008, 2009, 2010; Hamburg University of Technology
 *
 * > TECHNICAL REALIZATION
 *   Christian Renner <christian.renner@tu-harburg.de>
 *   Leo Krueger
 *   Sigurd Spieckermann
 *
 * > CONCEPT
 *   Peter Baasch
 *   Detlev Bieler
 *   Thomas Czerwionka
 *   Thomas Hapke
 *   Soenke Knutzen
 *   Corinna Peters
 *   Christian Renner
 *   Volker Turau
 *   Olav Wilde
 *
 **************************************************************************
 * This file is part of "StudIPort 2.0 ePortfolio".
 *
 * "StudIPort 2.0 ePortfolio" is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * "StudIPort 2.0 ePortfolio" is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with "StudIPort 2.0 ePortfolio".
 * If not, see <http://www.gnu.org/licenses/>.
 *
 *************************************************************************/

require_once('StudIPortPart.class.php');
require_once('StudIPortTools.lib.php');


class StudIPortQuestionList extends StudIPortPart
{
        // constants, filters for data loading
	const FILTER_ALL     = 0;
	const FILTER_EXPIRE  = 1;

	// members
	protected $viewId;
	protected $questions;

	public function __construct(StudIPortUser &$user, $viewId = null) {
		parent::__construct($user);
		$this->viewId    = $viewId;
		$this->questions = array();
	}
	
	/** loads files associated with matrix
	 * @see StudIPortMatrixBase::loadData()
	 * @param void
	 */
	public function loadData($filter = self::FILTER_ALL) {
		if (! empty($this->viewId)) {
			// now check if user has access to the corresponding question
			// TODO is this necessary?
			$res = array();
			if (! validateViewAccess($this->viewId, $this->user->getUserId(), $res, QUESTION_ROLE_OWNER)) {
				// ERROR
				return;
			}
		} else {
			// now check if user has access to the corresponding question
			$res = array();
			// FIXME what to check here?
/*			if (! validateViewAccess($this->viewId, $this->user->getUserId(), $res, QUESTION_ROLE_ALIEN)) {
				// ERROR
				return;
			}*/
		}


		// if a view is specified, get files of that view for the checkboxes
		$whereCl = "1";
		if (! empty($this->viewId)) {
			$whereCl = "view_id = '". intval($this->viewId) ."'";
		}

		// apply filter, if any
		if ($filter === self::FILTER_EXPIRE) {
			$whereCl .= "  AND view_id IN ( SELECT view_id FROM studiport_view WHERE user_id='". $this->user->getUserId() ."')".
			            "  AND (expires AND DATEDIFF(expires, now()) BETWEEN 0 AND ". STUDIPORT_DAYS_NEW .")";
		}

		$sql =& $this->sql;
	
		// get questions associated with this view	
		$sql->query('SELECT '.
                             '  question_id, '.
//                             '  DATE_FORMAT(q.created, \'%%e. %%b %%Y\') AS created, '.
		             '   IF(q.expires, DATE_FORMAT(q.expires, \'%d.%m.%Y\'), NULL) as expires,' .
		             '  IF(expires,expires<CURDATE(),FALSE) AS expired, '.
                             '  SUBSTRING(q.text, 1, '. STUDIPORT_QUESTION_MAX_DISP_LENGTH .') AS text, '.
                             '  q.public, '.
                             '  SUM(viewed=\'N\') AS numNewResponses, '.
		             '  COUNT(viewed) AS numResponses, '.
		             '  (SELECT COUNT(*) FROM studiport_feedback_request WHERE question_id=q.question_id) AS numRequests '.
                             'FROM studiport_feedback_question AS q '.
                             '  LEFT JOIN studiport_feedback_response USING(question_id) '.
                             "WHERE $whereCl ".
                             'GROUP BY question_id '.
                             'ORDER BY q.created DESC');

		while ($sql->next_record()) {
			$r = $sql->get_record();
			$r['text'] = textAbbreviate($r['text'], STUDIPORT_QUESTION_MAX_DISP_LENGTH);
			array_push($this->questions, $r);
		}
	}

	public function getNum() {
		return count($this->questions);
	}

	public function render(Flexi_TemplateFactory &$factory, $templateFilename) {
                parent::render($factory, $templateFilename);
                $this->template->set_attribute('viewId', $this->viewId);
                $this->template->set_attribute('questions', $this->questions);
                return $this->template->render();
        }
}
?>
