<?php
/**************************************************************************
 * $Id: $
 *
 * Copyright (C) 2008, 2009, 2010; Hamburg University of Technology
 *
 * > TECHNICAL REALIZATION
 *   Christian Renner <christian.renner@tu-harburg.de>
 *   Leo Krueger
 *   Sigurd Spieckermann
 *
 * > CONCEPT
 *   Peter Baasch
 *   Detlev Bieler
 *   Thomas Czerwionka
 *   Thomas Hapke
 *   Soenke Knutzen
 *   Corinna Peters
 *   Christian Renner
 *   Volker Turau
 *   Olav Wilde
 *
 **************************************************************************
 * This file is part of "StudIPort 2.0 ePortfolio".
 *
 * "StudIPort 2.0 ePortfolio" is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * "StudIPort 2.0 ePortfolio" is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with "StudIPort 2.0 ePortfolio".
 * If not, see <http://www.gnu.org/licenses/>.
 *
 *************************************************************************/

require_once('StudIPortPart.class.php');
require_once('StudIPortAvatar.system.php');

/** @class StudIPortRequestList
 */
class StudIPortRequestList extends StudIPortPart
{
	protected $questionId;
	protected $users;
	protected $requests;

	public function __construct(StudIPortUser &$user, $questionId = null) {
		parent::__construct($user);
		$this->questionId = $questionId;
		$this->users      = array();
		$this->requests   = array();
	}
	
	/** loads files associated with matrix
	 * @see StudIPortMatrixBase::loadData()
	 * @param void
	 */
	public function loadData() {
		// if a view is specified, get files of that view for the checkboxes
		if (empty($this->questionId)) {
			// ERROR
			return;
		}
		// now check if user has access to the corresponding question
		// TODO is this necessary?
		$res = array();
		if (! validateQuestionAccess($this->questionId, $this->user->getUserId(), $res, QUESTION_ROLE_OWNER)) {
			// ERROR
			return;
		}
		
		$sql =& $this->sql;
	
		// get users associated with this view of this question
		$sql->queryf('SELECT DISTINCT'.
                             '  user_id '.
		             'FROM studiport_view_access '.
                             'WHERE view_id = ( '.
		             '    SELECT DISTINCT view_id '.
		             '    FROM studiport_feedback_question '.
		             '    WHERE question_id=\'%d\') ',
                             $this->questionId);

		$idLst = array();
		while ($sql->next_record()) {
			$idLst[] = $sql->f('user_id');
		}
		StudIPortUser::getByUserId($this->users, $idLst);

		// get requests
		$sql->queryf('SELECT DISTINCT'.
                             '  user_id '.
		             'FROM studiport_feedback_request '.
                             'WHERE question_id = %d',
		             $this->questionId);

		while ($sql->next_record()) {
			$this->requests[$sql->f('user_id')] = 1;
		}
	}

	public function getNum() {
		return count($this->requests);
	}

	public function render(Flexi_TemplateFactory &$factory, $templateFilename) {
		parent::render($factory, $templateFilename);
		$this->template->set_attribute('questionId', $this->questionId);
		$this->template->set_attribute('users', $this->users);
		$this->template->set_attribute('requests', $this->requests);
		return $this->template->render();
	}
}
?>
