<?php
/**************************************************************************
 * $Id: $
 *
 * Copyright (C) 2008, 2009, 2010; Hamburg University of Technology
 *
 * > TECHNICAL REALIZATION
 *   Christian Renner <christian.renner@tu-harburg.de>
 *   Leo Krueger
 *   Sigurd Spieckermann
 *
 * > CONCEPT
 *   Peter Baasch
 *   Detlev Bieler
 *   Thomas Czerwionka
 *   Thomas Hapke
 *   Soenke Knutzen
 *   Corinna Peters
 *   Christian Renner
 *   Volker Turau
 *   Olav Wilde
 *
 **************************************************************************
 * This file is part of "StudIPort 2.0 ePortfolio".
 *
 * "StudIPort 2.0 ePortfolio" is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * "StudIPort 2.0 ePortfolio" is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with "StudIPort 2.0 ePortfolio".
 * If not, see <http://www.gnu.org/licenses/>.
 *
 *************************************************************************/

require_once('StudIPortPart.class.php');
require_once('StudIPortAvatar.system.php');

class StudIPortViewListAlien extends StudIPortPart
{
        // constants, filters for data loading
        const FILTER_ALL       = 0;
        const FILTER_NEW       = 1;
        const FILTER_MODIFIED  = 2;

	protected $userList;
	protected $viewByUser;  // hashmap user-id => array( views )
	protected $numViews;

	public function __construct(StudIPortUser &$user) {
		parent::__construct($user);
        	$this->userList   = array();
        	$this->viewByUser = array();
        	$this->numViews   = 0;
	}
	
	/** loads files associated with matrix
	 * @see StudIPortMatrixBase::loadData()
	 * @param void
	 */
	public function loadData($filter = self::FILTER_ALL) {

		$idLst = array();

		if (empty($this->user)) {
			// TODO error message
			return;
		}

		// establish DB connection
		// TODO
		$dbOwners   = new StudIPortDB();
		$dbViews    = new StudIPortDB();
		$dbFeedback = new StudIPortDB();

                // user id
                $user_id = $this->user->getUserId();

		// set up where clause depending on filter
		$whereClAdd = "";
		if ($filter == self::FILTER_NEW) {
			$whereClAdd = "AND (access.viewed != 'Y')";
		} else if ($filter == self::FILTER_MODIFIED) {
			$whereClAdd = "AND (access.viewed = 'Y' AND access.accesstime < view.edited)";
		}

                // obtain users with a view for me
		$dbOwners->queryf(
                          "SELECT DISTINCT view.user_id "
                        . "FROM studiport_view view"
                        . "  LEFT JOIN studiport_view_access access USING (view_id)"
                        . "  WHERE access.user_id='%s'"
			. "    AND (NOT expires OR expires >= CURDATE())"
			. "    $whereClAdd",
			$user_id);

		// and then get the views provided by the users
                while ($dbOwners->next_record()) {
	                $dbViews->queryf(
				  " SELECT"
				. "   view_id,"
				. "   name,"
//				. "   DATE_FORMAT(expires, '%%e. %%b %%Y') as expires,"
				. "   IF(expires, DATE_FORMAT(expires, '%%d.%%m.%%Y'), NULL) as expires,"
//				. "   IF(accesstime, DATE_FORMAT(accesstime, '%%d.%%m.%%Y'), NULL) as accesstime,"
//				. "   IF(edited, DATE_FORMAT(edite, '%%d.%%m.%%Y'), NULL) as edited,"
				. "   (viewed != 'Y' OR access.accesstime < view.edited) AS modified,"
//				. "   CHAR_LENGTH(descr) > 0 AS hasInfo"
				. "   descr"
				. " FROM studiport_view AS view"
				. " LEFT JOIN studiport_view_access AS access USING(view_id)"
//				. " LEFT JOIN studiport_feedback_request AS request USING(response.user_id=view.user_id)"
				. " WHERE view.user_id='%s'"
				. "   AND access.user_id='%s'"
				. "   AND (NOT expires OR expires >= CURDATE())"
				. "   $whereClAdd"
				. " ORDER BY name",
				$dbOwners->f('user_id'), $user_id);

			// skip, if there is no view
			if ($dbViews->num_rows() == 0) {
				continue;
			}

			// count number of views
			$this->numViews += $dbViews->num_rows();

			// push user to list of those with a view for me
			$idLst[] = $dbOwners->f('user_id');
			$this->viewByUser{$dbOwners->f('user_id')} = array();

			while ($dbViews->next_record()) {
				// get number of requests and responses separately, as this may likely
				// provoke errors if merged into the dbViews query
				$dbFeedback->queryf(
					  " SELECT"
					. "   COUNT(*) AS numQuestions,"
					. "   COUNT(request.user_id) AS numRequests"
					. " FROM studiport_feedback_question AS question"
					. "   LEFT JOIN studiport_feedback_request AS request USING (question_id)"
					. " WHERE view_id='%d'"
					. "   AND (NOT expires OR expires >= CURDATE())"
					. "   AND (request.user_id='%s' OR ISNULL(request.user_id))"
					. " GROUP BY view_id",
					$dbViews->f('view_id'), $user_id);

				if ($dbFeedback->next_record()) {
					$feedback = $dbFeedback->get_record();
				} else {
					$feedback = array('numRequests' => 0, 'numQuestions' => 0);
				}

				// add view to user array
				$this->viewByUser{$dbOwners->f('user_id')}[] = array_merge($dbViews->get_record(), $feedback);
				//array_push($usr['views'], array_merge($dbViews->get_record(), $feedback));
			}

			// append user struct with all assoc views
//                        array_push($this->userList, $usr);
                }

		// get info about all users with views for me
		StudIPortUser::getByUserId($this->userList, $idLst);
        }


	/** @see StudIPortBase::render() */
	public function render(Flexi_TemplateFactory &$factory, $templateFilename) {
		parent::render($factory, $templateFilename);
	
		$this->template->set_attribute('userList',   $this->userList);
		$this->template->set_attribute('viewByUser', $this->viewByUser);
		
		return $this->template->render(); 
	}
	
	public function getNum() {
		return $this->numViews;
	}
}
?>
