<?php
/**************************************************************************
 * $Id: $
 *
 * Copyright (C) 2008, 2009, 2010; Hamburg University of Technology
 *
 * > TECHNICAL REALIZATION
 *   Christian Renner <christian.renner@tu-harburg.de>
 *   Leo Krueger
 *   Sigurd Spieckermann
 *
 * > CONCEPT
 *   Peter Baasch
 *   Detlev Bieler
 *   Thomas Czerwionka
 *   Thomas Hapke
 *   Soenke Knutzen
 *   Corinna Peters
 *   Christian Renner
 *   Volker Turau
 *   Olav Wilde
 *
 **************************************************************************
 * This file is part of "StudIPort 2.0 ePortfolio".
 *
 * "StudIPort 2.0 ePortfolio" is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * "StudIPort 2.0 ePortfolio" is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with "StudIPort 2.0 ePortfolio".
 * If not, see <http://www.gnu.org/licenses/>.
 *
 *************************************************************************/


abstract class Iface_StudIPortDB {
	// perform a DB query
	abstract public function query($q);

	// escape a value to be written into the DB
	abstract public function escape($v);

	// convert a string from UTF8 to DB character set
	abstract public static function convertToDB($v);

	// convert a string from DB character set to UTF8
	abstract public static function convertFromDB($v);

	// perform a query with formatting (as printf does)
	public function queryf($format /* , .. */) {

		// get args
		$args = func_get_args();

		// get format string
		$format = array_shift($args);

		// escape arguments
		foreach ($args as $key => &$value) {
			// NOTE the escape method must be provided by the inheriting class!
			$args[$key] = $this->escape($value);
		}

		// do something
		return $this->query(vsprintf($format, $args));
	}

	// get next record from current data set, must be assoc array: fieldname=>value
	abstract public function next_record();

	// get access to current record
	abstract public function get_record();
	
	// return value of field with name 'fn' of current record
	abstract public function f($fn);

	// return number of rows in data set
	abstract public function num_rows();

	// return index of current row in data set
	abstract public function cur_row();

	// return number of rows affected by last query
	abstract public function affected_rows();
};

?>
