<?php
/**************************************************************************
 * $Id: $
 *
 * Copyright (C) 2008, 2009, 2010; Hamburg University of Technology
 *
 * > TECHNICAL REALIZATION
 *   Christian Renner <christian.renner@tu-harburg.de>
 *   Leo Krueger
 *   Sigurd Spieckermann
 *
 * > CONCEPT
 *   Peter Baasch
 *   Detlev Bieler
 *   Thomas Czerwionka
 *   Thomas Hapke
 *   Soenke Knutzen
 *   Corinna Peters
 *   Christian Renner
 *   Volker Turau
 *   Olav Wilde
 *
 **************************************************************************
 * This file is part of "StudIPort 2.0 ePortfolio".
 *
 * "StudIPort 2.0 ePortfolio" is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * "StudIPort 2.0 ePortfolio" is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with "StudIPort 2.0 ePortfolio".
 * If not, see <http://www.gnu.org/licenses/>.
 *
 *************************************************************************/


abstract class Iface_StudIPortUser {
	const NOBODY = "nobody";

	protected static $theUser_ = null;  // the currently logged in user

	static public function & theUser() {
		if (is_null(self::$theUser_)) {
			self::$theUser_ = new StudIPortUser();
		}
		return self::$theUser_;
	}

	// return user id
	// user id must fit into a varchar(32) field in MySQL!
	abstract public function getUserId();
	
	// return real name of user in format:
	// rev == false:   Max Mustermann
	// rev == true:    Mustermann, Max
	abstract public function getRealName($rev = false);

	// get formatted realname of user identified by user_id
	// same as above, but for user with user_id provided by function call
	abstract public static function getRealNameOf($user_id, $rev = false);

	// find/search users by name
	// @param lst target of search: a (possibly sorted) array of user entries
	//        each entry is an assoc array with (user_id, username, fullname)
	// @param query string with comma-separated search keys, e.g. "Max Mustermann"
	//        The search engine SHOULD search in firstname and lastname for
	//        each of the keys in the query with an OR conjunction
	// @param Maximum number of search results (-1 of none)
	// @return number of elements in lst, -1 on an error
	abstract public static function searchByName(& $lst, $query, $limit = -1);

	// get users by id
	// idLst may be a single ID or a list (array) of IDs
	// parameters and returns are the same as above (omitting the limit paramter)
	abstract public static function getByUserId(& $lst, $idLst);
};

?>
