<?php
/**************************************************************************
 * $Id: $
 *
 * Copyright (C) 2008, 2009, 2010; Hamburg University of Technology
 *
 * > TECHNICAL REALIZATION
 *   Christian Renner <christian.renner@tu-harburg.de>
 *   Leo Krueger
 *   Sigurd Spieckermann
 *
 * > CONCEPT
 *   Peter Baasch
 *   Detlev Bieler
 *   Thomas Czerwionka
 *   Thomas Hapke
 *   Soenke Knutzen
 *   Corinna Peters
 *   Christian Renner
 *   Volker Turau
 *   Olav Wilde
 *
 **************************************************************************
 * This file is part of "StudIPort 2.0 ePortfolio".
 *
 * "StudIPort 2.0 ePortfolio" is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * "StudIPort 2.0 ePortfolio" is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with "StudIPort 2.0 ePortfolio".
 * If not, see <http://www.gnu.org/licenses/>.
 *
 *************************************************************************/

require_once('StudIPortUser.iface.php');

require_once('StudIPortDB.system.php');

class StudIPortUser extends Iface_StudIPortUser {
	protected $userid;

	public function __construct($user_id = false) {
		if ($user_id === false) {
			if (empty($_SESSION['user_id'])) {
//				die("You should never reach this line!");
				// we have an user without login
				// TODO is it smart to put NOBODY into the session var rather than just into user_id?
				$_SESSION['user_id'] = StudIPortUser::NOBODY;
			}
			$user_id = $_SESSION['user_id'];
		}
		$this->userid = $user_id;
	}

	// return user id as string
	public function getUserId() {
		return $this->userid;
	}
	
	// return 
	public function getRealName($rev = true) {
		return self::getRealNameOf($this->userid, $rev);
	}

	private static function getLDAPIdFromId($user_id) {
		if (STUDIPORT_LDAP_UID_BINARY) {
			$hexId = str_replace("-", "", $user_id);
			$id ='';
			for ($i = 0; $i <= strlen($hexId)-2; $i = $i+2){
				$id .=  "\\".substr($hexId, $i, 2);
			}
		} else {
			$id = $user_id;
		}
		return $id;
	}

	private static function getUserAttributesFromLDAP($attrs) {
		return array(
			'user_id'  => bin2hex($attrs[STUDIPORT_LDAP_ATTR_UID][0]),
			'username' => $attrs[STUDIPORT_LDAP_ATTR_LOGIN][0],
			'fullname' => $attrs[STUDIPORT_LDAP_ATTR_FIRSTNAME][0] . ", " . $attrs[STUDIPORT_LDAP_ATTR_GIVENNAME][0]
		);
	}

	private static function connectToLDAPServer(&$conn, $user = STUDIPORT_LDAP_USER, $password = STUDIPORT_LDAP_PASSWORD) {
		$ldapuri = "ldap://".STUDIPORT_LDAP_HOST.":".STUDIPORT_LDAP_PORT;
		$conn = ldap_connect($ldapuri)
			or die("Could not connect to LDAP server.");
		ldap_set_option($conn, LDAP_OPT_PROTOCOL_VERSION, STUDIPORT_LDAP_VERSION);
		$result = ldap_bind($conn, $user, $password);
		return $result;
	}

	// authenticate user and password
	public static function authenticate($user, $password) {
		$result = self::connectToLDAPServer($conn, $user.STUDIPORT_LDAP_USERPOSTFIX, $password);
		if ($result) {
			$filter = "(".STUDIPORT_LDAP_ATTR_LOGIN."=".$user.")";	
			$justthese = array(STUDIPORT_LDAP_ATTR_UID);
			$sr = ldap_search($conn, STUDIPORT_LDAP_BASEDN, $filter,$justthese);
			$entry = ldap_first_entry($conn, $sr);
			$attrs = ldap_get_attributes($conn, $entry);
			$id = bin2hex($attrs[STUDIPORT_LDAP_ATTR_UID][0]);
			ldap_free_result($sr);
			return $id;
		} else {
			return false;
		}
	}

	public static function getRealNameOf($user_id, $rev = true) {
		$result = self::connectToLDAPServer($conn);
		if ($result) {
			$id = self::getLDAPIdFromId($user_id);
			$filter = "(&(objectClass=user)(".STUDIPORT_LDAP_ATTR_UID."=".$id."))";
			$justthese = array(STUDIPORT_LDAP_ATTR_FIRSTNAME, STUDIPORT_LDAP_ATTR_GIVENNAME);
			$sr = ldap_search($conn, STUDIPORT_LDAP_BASEDN, $filter,$justthese);
			$entry = ldap_first_entry($conn, $sr);
			$attrs = ldap_get_attributes($conn, $entry);
			ldap_free_result($sr);
			if ($rev) {
				return $attrs[STUDIPORT_LDAP_ATTR_FIRSTNAME][0] . ", " . $attrs[STUDIPORT_LDAP_ATTR_GIVENNAME][0];
			} else {
				return $attrs[STUDIPORT_LDAP_ATTR_GIVENNAME][0] . " " . $attrs[STUDIPORT_LDAP_ATTR_FIRSTNAME][0];
			}
		} else {
			return false;
		}
	}

	// search/find users by name
	public static function searchByName(& $lst, $query, $limit = 0) {
                // search in lastname and given name, split query at whitespaces
                $tokLst = split(' +', $query);
                if (count($tokLst) <= 0) {
                        return -1;
                }
                $filter = "(&(objectClass=user)(|";
                foreach ($tokLst as $tok) {
                        $filter .= "(".STUDIPORT_LDAP_ATTR_FIRSTNAME."=*".$tok."*)(".STUDIPORT_LDAP_ATTR_GIVENNAME."=*".$tok."*)";
                }
		$filter .="))";

                // limit number of results, if desired
                $limit = intval($limit);

		$result = self::connectToLDAPServer($conn);
		if (! $result) {
			return (-1);
		}

		$justthese = array(
			STUDIPORT_LDAP_ATTR_LOGIN, STUDIPORT_LDAP_ATTR_UID,
			STUDIPORT_LDAP_ATTR_FIRSTNAME, STUDIPORT_LDAP_ATTR_GIVENNAME);
		$sr = ldap_search($conn, STUDIPORT_LDAP_BASEDN, $filter,$justthese);
		$entry = ldap_first_entry($conn, $sr);
               	$lst = array();
		while ($entry) {
			$attrs = ldap_get_attributes($conn, $entry);
			$lst[] = self::getUserAttributesFromLDAP($attrs);
			$entry = ldap_next_entry($conn, $entry);
		}
		ldap_free_result($sr);

                return count($lst);
	}


	public static function getByUserId(& $lst, $idLst) {
		if (! is_array($idLst)) {
			$idLst = array($idLst);  // convert to array for ease of use
		}
                $idLst = array_unique($idLst);   // throw out duplicates

		$result = self::connectToLDAPServer($conn);
		if (! $result) {
			return -1;
		}

                $filter = "(&(objectClass=user)(|";
		foreach ($idLst as $user_id) {
			$id = self::getLDAPIdFromId($user_id);
			$filter .= "(".STUDIPORT_LDAP_ATTR_UID."=".$id.")";
		}
		$filter.="))";
		$justthese = array(
			STUDIPORT_LDAP_ATTR_LOGIN, STUDIPORT_LDAP_ATTR_UID,
			STUDIPORT_LDAP_ATTR_FIRSTNAME, STUDIPORT_LDAP_ATTR_GIVENNAME);
                $sr = ldap_search($conn, STUDIPORT_LDAP_BASEDN, $filter,$justthese);
                $entry = ldap_first_entry($conn, $sr);

                // put data in list/array
               	$lst = array();
		while ($entry) {
			$attrs = ldap_get_attributes($conn, $entry);
			$lst[] = self::getUserAttributesFromLDAP($attrs);
			$entry = ldap_next_entry($conn, $entry);
		}
		ldap_free_result($sr);

                return count($lst);
	}
};

?>
