var StudIPort =
{
	urlAjaxServer : StudIPortUrl  + "StudIPortAjaxServer.php",

	ajax   : {},
	box    : {},
	cache  : {},
	file   : {},
	matrix : {},
	msgbox : {},
	upload : {},
	view   : {},
	
	expand : function(btn, objId)
	{
		obj = $(objId);
		btn = $(btn);
		
		if (obj.getStyle("display") == "none") {
			//obj.setStyle({display: 'block'});
			Effect.BlindDown(obj, { duration: 0.5 });
			btn.src = btn.src.sub('expand', 'collapse');
		} else {
			//obj.setStyle({display: 'none'});
			Effect.BlindUp(obj, { duration: 0.5 });
			btn.src = btn.src.sub('collapse', 'expand');
		}
	},
	
	/** selects all checkboxes in a form
	 * @param formId ID of form
	 * @param check  true: checks all boxes, false: unchecks all boxes
	 */
	selectCheckboxes : function(formId, check, optionalName)
	{
		form  = $(formId);
		
		if (typeof optionalName == 'undefined') {
			boxes = form.getInputs('checkbox'); // get all checkboxes of form
		} else {
			boxes = form.getInputs('checkbox', optionalName); // get all checkboxes of form
		}
		
		boxes.each(function(e) { e.checked = check });
	},
	
	/** inverts all checkboxes in a form
	 * @param formId ID of form
	 */
	invertCheckboxes : function(formId)
	{
		form  = $(formId);
		
		if (typeof optionalName == 'undefined') {
			boxes = form.getInputs('checkbox'); // get all checkboxes of form
		} else {
			boxes = form.getInputs('checkbox', optionalName); // get all checkboxes of form
		}
		
		boxes.each(function(e) { e.checked = !e.checked });
	},

        /**
         * marks all checkboxes belonging to a list as selected (and the others as unselected)
         *
         * @param src    form containing the file checkboxes
         * @param lst    list of file ids that belong to the view
         */
	updateCheckboxes : function(formId, lst)
	{
		if (lst == null) {
			return;
		}

		f = $(formId);
		if (f == null ) {
			return;
		}

		// first uncheck/check files
		f.getInputs('checkbox').each(function(item) {
			item.checked = false;
			for (i = 0; i < lst.length; i++) {
				if (lst[i] == item.value) {
	                        	item.checked = true;
					lst.splice(i, 1);
				}
			}
		});
        },


	
	/**
	 * looks up Stud.IP users from database via AJAX and stores them as a list in the given
	 *
	 * @param dst  identifier of element used to store the received list of users
	 * @param src  identifier of element holding the search/query mask
	 * @param mb   element used as message box for feedback to user
	 */
	doUserSearch : function(dst, src, mb)
	{
		// first check number of chars in query
		var q = $F(src).strip();
		
		if (q.length < 3) {
			// issue corresponding error message
			StudIPort.msgBox.update(mb, "Suchmaske muss mindestens 3 Buchstaben enthalten", StudIPort.msgBox.ERROR);
			return;
		}

		// reset message box
		StudIPort.msgBox.update(mb, "Warte auf Daten ...", this.msgBox.WAITING);
		
		StudIPort.ajax.request({cmd: 'userSearch', qStr: q, mb: mb, dst: dst}, this.doUserSearchSuccess, this.doUserSearchFailure);
	},
	
	doUserSearchSuccess : function(res,par)
	{
		// then update list and create new Sortable
		$(par.dst).update(res.htmlContent);
		StudIPort.view.initUserSelectSortable();

		// finally, issue warnings if there are any
		if (res.warnings != null)
		{
			StudIPort.msgBox.update(par.mb, res.warnings, StudIPort.msgBox.WARNING);
		}
		else
		{
			StudIPort.msgBox.update(par.mb, "", StudIPort.msgBox.WAITING);
		}
	},
	
	doUserSearchFailure : function(res,par)
	{
		StudIPort.msgBox.update(mb, res.errorMsg, StudIPort.msgBox.ERROR);
	}
};

/** User Agent (Browserkennung) auf einen bestimmten Browsertyp pr�fen, Funktion aus Tutorial im Internet (leo)
 * @param name  name of the browser to compare with current browsers name
 * @return true, if the provided browser name is contained in the actual browser name; false else
 */
function checkBrowserName(name)
{
	// NOTE should be part of Prototype (?)
	agent = navigator.userAgent.toLowerCase();
	
	if (agent.indexOf(name.toLowerCase()) > -1) {
		return true;
	}
	
	return false;
}

function FormStatus(form, msgBox, defaultClass, editedClass, errorClass) {
	this.theForm = $(form);
	this.msgBox  = $(msgBox);
	this.defaultClass   = defaultClass ? defaultClass : "";
	this.editedClass    = editedClass ? editedClass : "inpEdited";
	this.errorClass     = errorClass ? errorClass : "inpError";

	this.changedObjects = [];
}

/**
 * notifier for changed form fields. Changes css display class and stores field
 * in order to transmit changes, if user saves the form
 *
 * @param obj  form field (or its name) that has been changed, e.g., <input>
 */
FormStatus.prototype.change = function(obj) {
	// indicate changed data using msg box
	this.printMsg("Daten ge&auml;ndert und ungespeichert", StudIPort.msgBox.CHANGED);
	
	// get changed object
	obj = $(obj);
	if (obj == null) {
		return;
	}

	// insert into list and update display css class
	if ((pos = this.changedObjects.indexOf(obj)) == -1) {
		this.changedObjects.push(obj);
		obj.className = this.editedClass;
	}
}

/**
 * function to save a modified form. Transmits all changed and hidden fields via
 * AJAX.
 *
 * @param command command to be executed by the server-side script
 */
FormStatus.prototype.save = function(command, addParams) {
	fs     = this;
	params = {};

	// check, if anything changed at all
	if (this.changedObjects.length == 0) {
		this.printMsg("Keine &Auml;nderungen vorgenommen", StudIPort.msgBox.OK);
	}
	
	// setup changed parameters	
	this.changedObjects.each(function(obj) {
		params[obj.id] = $F(obj);
	});

	// additionally send all hidden fields
	if (this.theForm != null) {
		this.theForm.getInputs('hidden').each(function(obj) {
			params[obj.id] = $F(obj);
		});
	}
	
	// finally add the AJAX request command
	params = $H(addParams).merge(params);
	params.set('cmd', command);  // write this explicitely

	// update message box
	this.printMsg("&Uuml;bertrage Daten", StudIPort.msgBox.WAITING);
	// final AJAX request
	StudIPort.ajax.request(params, function(res,par) {fs.saveSuccess(res,par)}, function(res,par) {fs.saveFailure(res,par)});
}

FormStatus.prototype.saveSuccess = function(res,par)
{
	this.changedObjects.each(function(obj) {
		obj.className = this.defaultClass;
	});

	this.changedObjects.clear();
	
	// print success message or warnings
	if (res.warnings == null) {
		this.printMsg("&Auml;nderungen erfolgreich gespeichert", StudIPort.msgBox.OK);
	} else {
		this.printMsg(res.warnings, StudIPort.msgBox.WARNING);
	}

	// update fields in form, if any
	if (res.formUpdates) {
		this.formUpdate(res.formUpdates);
	}
}

FormStatus.prototype.saveFailure = function(res,par)
{
	// todo show all error messages and highlight corresponding inputs
	this.printMsg(res.errorMsg, StudIPort.msgBox.ERROR);
}

/**
 * function to reload a (modified) form. Requests the last saved version of a dataset
 *
 * @param command command to be executed by the server-side script
 */
FormStatus.prototype.abort = function(command, addParams) {
	fs     = this;
	params = {};

	// prepare command/parameters
	params = $H(addParams);
	params.set('cmd', command);  // write this explicitely

	// update message box
	this.printMsg("Hole Daten", StudIPort.msgBox.WAITING);

	// AJAX Request
	StudIPort.ajax.request(params, function(res,par) {fs.abortSuccess(res,par)}, function(res,par) {fs.abortFailure(res,par)});
}

FormStatus.prototype.abortSuccess = function(res,par)
{
	this.changedObjects.each(function(obj) {
		obj.className = this.defaultClass;
	});
	
	this.changedObjects.clear();
	this.printMsg("Daten zur&uuml;ckgesetzt", StudIPort.msgBox.OK);
	
	// write updates/original values
	if (res.formUpdates) {
		this.formUpdate(res.formUpdates);
	}
}

FormStatus.prototype.abortFailure = function(res,par)
{
	this.printMsg(res.errorMsg, StudIPort.msgBox.ERROR);
}
					

/**
 * updates fields of a form using the key-value pairs of the update parameter
 *
 * @param updates as key-value pairs
 */
FormStatus.prototype.formUpdate = function(updates) {
	// get form elements
	var textAreas   = $A(this.theForm.getElementsByTagName('textarea')).map(Element.extend);
	var textInputs  = this.theForm.getInputs("text");
	var checkFields = this.theForm.getInputs("checkbox");

	// update fields
	$H(updates).each(function(pair) {
		field = $(pair.key);
		if (field != null) {
			if (textInputs.indexOf(field) != (-1) ||
			    textAreas.indexOf(field) != (-1))
			{
				field.value = pair.value;
			} else if (checkFields.indexOf(field) != (-1)) {
				field.checked = (field.value == pair.value);
			}
		}
	});
}

/**
 * prints the provided message to the message box associated with the form
 *
 * @param msgs message or array of messages
 * @param type type of message (@see MSGBOX_*)
 */
FormStatus.prototype.printMsg = function(msgs, type) {
	if (this.msgBox != null) {
		StudIPort.msgBox.update(this.msgBox, msgs, type);
	} else {
		alert(msgs);
	}
}

// TABBING

function Tabs(tabPrefix, tabContentPrefix) {
	this.tab_activeTab      = -1;
	this.tab_prefix         = tabPrefix;
	this.tab_content_prefix = tabContentPrefix;
}

/**
 */
Tabs.prototype.show = function(index) {
	if (index == this.tab_activeTab) {
		return;
	}
	
	// get references to tabs and contents
	var tabOld     = $(this.tab_prefix + this.tab_activeTab);
	var tabNew     = $(this.tab_prefix + index);
	var contentOld = $(this.tab_content_prefix + this.tab_activeTab);
	var contentNew = $(this.tab_content_prefix + index);

	// assign new classes
	if (tabOld != null) {
		tabOld.className = '';
	}
	if (tabNew != null) {
		tabNew.className = 'tabActive';
	}
	// NOTE check, if the content boxes really exist (they might not,
	// if there is no file assigned
	if (contentOld != null) {
		contentOld.hide();
	}
	if (contentNew != null) {
		contentNew.show();
	}
	
	this.tab_activeTab = index;
}


/**
 */
Tabs.prototype.highlight = function(index) {
	if (index == this.tab_activeTab) {
		return;
	}
	
	// get references to tabs and contents
	$(this.tab_prefix + index).className = "tabHover";
}

/**
 */
Tabs.prototype.dehighlight = function(index) {
	if (index == this.tab_activeTab) {
		return;
	}
	
	// get references to tabs and contents
	$(this.tab_prefix + index).className = "";
}
