<?php
/**************************************************************************
 * $Id:  $
 *
 * Copyright (C) 2008, 2009, 2010; Hamburg University of Technology
 *
 * > TECHNICAL REALIZATION
 *   Christian Renner <christian.renner@tu-harburg.de>
 *   Leo Krueger
 *   Sigurd Spieckermann
 *
 * > CONCEPT
 *   Peter Baasch
 *   Detlev Bieler
 *   Thomas Czerwionka
 *   Thomas Hapke
 *   Soenke Knutzen
 *   Corinna Peters
 *   Christian Renner
 *   Volker Turau
 *   Olav Wilde
 *
 **************************************************************************
 * This file is part of "StudIPort 2.0 ePortfolio".
 *
 * "StudIPort 2.0 ePortfolio" is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * "StudIPort 2.0 ePortfolio" is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with "StudIPort 2.0 ePortfolio".
 * If not, see <http://www.gnu.org/licenses/>.
 *
 *************************************************************************/

require_once('StudIPortDB.system.php');
require_once('StudIPortUser.system.php');

class StudIPortPDFView {
	protected $texFile         = null;
	protected $pdflatexExt     = array('aux', 'log', 'svn', 'uoc');  // extensions of files procuded by pdflatex

	protected $viewId          = -1;
	protected $competenceIds   = array();
	protected $competence      = array();
	protected $competenceDescr = array();
	protected $image           = array();
	protected $owner           = null;
	protected $files           = array();

	// string holding an error message
	protected $errMsg          = false;


	// constructor
	public function __construct($viewId) {
		$this->viewId = $viewId;
	}

	public function __destruct() {
		// remove temp files
		if ($this->texFile) {
			@unlink($this->texFile);
		}
		if ($this->pdfFile) {
			@unlink($this->pdfFile);
		}
	}

	public function create() {
		if (! $this->loadData()) {
			$this->errMsg = "Konnte Daten nicht laden";
			return false;
		}
		if (! $this->createLaTeX()) {
			$this->errMsg = "Konnte LaTeX-Quelle nicht erzeugen";
			return false;
		}
		if (! $this->createPDF()) {
			$this->errMsg = "Konnte PDF nicht erstellen";
			return false;
		}
		return true;
	}

	public function getPDF() {
		if (file_exists($this->pdfFile)) {
			return file_get_contents($this->pdfFile);
		} else {
			return false;
		}
	}

	public function get_error() {
		return $this->errMsg;
	}


	/**
	 * convert a string from the database into LaTeX semantic
	 */
	private static function toLaTeX($str) {
		$src  = array("\\", "\r\n", "\n", "_", "$$", "&", "%", "<ul><li>", "</li><li>", "</li></ul>", "\"", "ffi", "ffl", "ff", "fi", "fl", "AV");
		$dst = array("$$\\backslash$$", "\n", "\n\n", "\\_", "\\$$", "\\&", "\\%", " ", ", ", ". ", "''", "f\"|f\"|i", "f\"|f\"|l", "f\"|f", "f\"|i", "f\"|l", "A\"|V");
		$convStr = str_replace($src, $dst, $str);
		return $convStr;
	}


	/**
	 * load data from DB
	 */
	protected function loadData() {
		$db = new StudIPortDB();

		// experiences
		$db->query('SELECT comp_id, title, descr FROM studiport_matrix_comp ORDER BY pos ASC');
		while ($db->next_record()) {
			$this->competenceIds[]                    = $db->f('comp_id');
			$this->competence{$db->f('comp_id')}      = self::toLaTeX($db->f('title'));
			$this->competenceDescr{$db->f('comp_id')} = self::toLaTeX($db->f('descr'));
		}

		// pics
		//$db->query('SELECT type_id, picture_print FROM studiport_file_types');
		$db->query('SELECT type_id, picture_print FROM studiport_file_types');
		while ($db->next_record()) {
			$this->image{$db->f('type_id')} = $db->f('picture_print');
		}

		// get owner of view
		$db->queryf('SELECT user_id FROM studiport_view WHERE view_id=%u', $this->viewId);
		if ($db->num_rows() != 1) {
			return false;
		}
		$db->next_record();
		$this->owner =& new StudIPortUser($db->f('user_id'));

		// files
		$db->queryf('SELECT title, comp_id, type_id, descr_ext FROM studiport_file file LEFT JOIN studiport_file_assoc USING (file_id) LEFT JOIN studiport_view_files USING (file_id) WHERE view_id=%u ORDER BY title', $this->viewId);
		while ($db->next_record()) {
			$this->files{$db->f('comp_id')}[] = $db->get_record();
		}

		return true;
	}


	/**
	 * generate LaTeX source file
	 */
	protected function createLaTeX()
	{
		// creat temp file to hold latex source
		$this->texFile = tempnam(sys_get_temp_dir(), 'view_');
		if (! $this->texFile) {
			// TODO err
			return false;
		}

		// open the file
		$fh = fopen($this->texFile, 'w');
		if (! $fh) {
			// TODO err
			@unlink($this->texFile);
			$this->texFile = null;
			return false;
		}

		// preamble, author, start doc
		fprintf($fh, "\n\\documentclass{eportfolio}\n");
		fprintf($fh, "\n\\author{%s}\n", self::toLaTeX($this->owner->getRealName(false)));
		fprintf($fh, "\n\\begin{document}\n");

		// print all files
		foreach ($this->competenceIds as $compId) {
			if (empty($this->files{$compId})) {
				continue;
			}

			fprintf($fh, "\n\n\n\\expertise{%s}{%s}\n", $this->competence{$compId}, $this->competenceDescr{$compId});

			foreach ($this->files{$compId} as $file) {
/*
				if ($curExperience != $file['exp_id']) {
					$curExperience = $file['exp_id'];
	
					fprintf($fh, "\n\n\\experience{%s}\n", $this->experience{$file['exp_id']});
				}
*/

				fprintf($fh, "\n\\edocument{%s}{%s}{%s}\n", self::toLaTeX($file['title']), $this->image{$file['type_id']}, self::toLaTeX($file['descr_ext']));
			}
		}

		// end of doc
		fprintf($fh, "\n\\end{document}\n");

			// close tex-source file
		fclose($fh);

		return true;
	}

	/**
	 * compile LaTeX to PDF
	 */
	protected function createPDF() {
		// setup folder for PDF creation and input filename
		$tmpDir = sys_get_temp_dir();
		$fn     = $this->texFile;

		// NOTE we need two PDF runs
		system("export TEXINPUTS=.:". STUDIPORT_TEXINPUTS .":\$TEXINPUTS; ".
		       "pdflatex -output-directory $tmpDir $fn >/dev/null 2>/dev/null </dev/null; ".
		       "pdflatex -output-directory $tmpDir $fn >/dev/null 2>/dev/null </dev/null; ",
		       $ret);

		// clean up after pdflatex run
		foreach ($this->pdflatexExt as $ext) {
			$fn = $this->texFile .".". $ext;
			if (file_exists($fn)) {
				@unlink($fn);
			}
		}

		// signal success status
		if ($ret == 0) {
			$this->pdfFile = $this->texFile .".pdf";
			return true;
		} else {
			return false;
		}
	}
};
?>
