%%
%% This is file 'eportfolio.cls'
%%
%% Copyright 2010 Christoph Weyer, Christian Renner
%%
%% This file is a class file for eportfolio print version.
%%
%% This system is distributed in the hope that it will be useful,
%% but WITHOUT ANY WARRANTY; without even the implied warranty of
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
%%

\RequirePackage{svn-multi}
\svnid{$Id: eportfolio.cls 8958 2010-08-03 11:17:41Z weyer $}

\makeatletter

\def\@ClassName{eportfolio}
\def\@ClassDesc{ePortfolio print version}
\def\@ClassVersion{0.1}
\def\@ClassFullVersion{\@ClassVersion\space(rev\space\svnfilerev)}

\NeedsTeXFormat{LaTeX2e}[1994/06/01]
\ProvidesClass{\@ClassName}[%
  \svnfileyear/\svnfilemonth/\svnfileday\space%
  v\@ClassFullVersion\space\@ClassDesc]
\typeout{Package \@ClassName, \csname ver@\@ClassName.cls\endcsname%
  ^^J\@spaces\@spaces\@spaces\@spaces\space\space
  Copyright (C) Christoph Weyer, Christian Renner, 2007-\svnfileyear^^J}

%%% configure underlying packages
\PassOptionsToClass{oneside,fontsize=12pt,a4paper}{scrbook}%

\LoadClass{scrbook}

%%%
%%%

\RequirePackage{ifpdf}

\ifpdf
    \RequirePackage[pdftex]{graphicx}

    \DeclareGraphicsExtensions{.jpg,.pdf,.png}
\else
    \RequirePackage[dvips]{graphicx}

    \DeclareGraphicsExtensions{.eps}
\fi


\RequirePackage[T1]{fontenc}
\RequirePackage[utf8]{inputenc}

% small optimizations
\RequirePackage{fixltx2e} % optimizes some magic things within LaTeX2e
\RequirePackage{ellipsis} % important for nice spacings around \dots

\RequirePackage[english,ngerman]{babel}
\selectlanguage{ngerman}

%\RequirePackage{lmodern}
%\RequirePackage{times}
%\RequirePackage[scaled=.90]{helvet}
%\RequirePackage{courier}

%\RequirePackage{lsyntax}
%\RequirePackage{uarial}

\RequirePackage{helvet}

\RequirePackage{needspace}

\RequirePackage{amsmath}
\RequirePackage{amssymb}
\RequirePackage{pifont}
%\RequirePackage[squaren]{SIunits}

\RequirePackage{everypage}
\RequirePackage{watermark}
\RequirePackage{pdfpages}

\RequirePackage{xcolor}[2005/12/21]

\providecolor{eblue}{rgb}{0.00,0.27,0.54}
\providecolor{egreen}{rgb}{0.00,0.45,0.53}


\DeclareFixedFont{\fontTitleDate}{T1}{phv}{m}{n}{20}
\DeclareFixedFont{\fontTitleMain}{T1}{phv}{m}{n}{38}
\DeclareFixedFont{\fontTitleMainBf}{T1}{phv}{b}{n}{38}
\DeclareFixedFont{\fontTitleName}{T1}{phv}{m}{n}{28}

\DeclareFixedFont{\fontToC}{T1}{phv}{m}{n}{12}

\renewcommand{\rmdefault}{phv}


\newcommand\varhrulefill[2][0pt]{\leavevmode\leaders\hrule height #2 depth #1\hfill\kern0pt}

\addtokomafont{chapter}{\color{eblue}\bfseries}

\RequirePackage{geometry}
\geometry{%
  offset={0cm,0cm},
  hmargin={3cm,5cm},
  vmargin={3.0cm,2.5cm}
}

\renewcommand*\chapterheadstartvskip{}


\setlength{\marginparsep}{1.7cm}
\setlength{\marginparwidth}{1.9cm}

\setlength{\parindent}{0pt}

\pagestyle{empty}
\renewcommand{\chapterpagestyle}{empty}

%%% the output handle
\newwrite\tuhh@hashFile

%%%
\newcommand{\toc@expertise}[3]{%
  \textcolor{eblue}{\textbf{#1}}~\textcolor{egreen}{\varhrulefill{1pt}}
  \marginpar{\textcolor{eblue}{Seite #3}}\par\relax

  \vspace*{4pt}\textcolor{egreen}{#2}
  \vspace*{2.5em plus 3.5em minus 2.0em}\par\relax
}

%%%
%%%
%%%
\newtoks\@temptoka
\newtoks\@temptokb
\newcommand{\expertise}[2]{%
  \addchap{#1}

  \begingroup
    \bfseries
    \color{eblue}
    #2
  \endgroup
  \vspace*{2em}\par\relax

  % important to protect the umlaute in the .uoc file
  \@temptoka{#1}%
  \@temptokb{#2}%
  \immediate\write\tuhh@hashFile{\string\toc@expertise{\the\@temptoka}{\the\@temptokb}{\thepage}}
}


%%%
%%%
%%%
\newcommand{\experience}[1]{%
  %\section*{#1}
}


%%%
%%%
%%%
\newcommand{\edocument}[3]{%
  \needspace{5\baselineskip}
  \textbf{\textcolor{eblue}{#1}~\textcolor{egreen}{\varhrulefill{1pt}}}

  \vspace*{2pt}
  \marginpar{%
    \vspace*{1pt}
    \begin{minipage}{\marginparwidth}
      \begin{flushright}
        \includegraphics{images/#2}
      \end{flushright}
    \end{minipage}
  }
  \begingroup\color{egreen}#3\endgroup
  \vspace*{1.5em plus 3em minus 0.5em}\par\relax
}


\usepackage{tikz}
\usetikzlibrary{calc}

%%%
%%%
%%%
\AddEverypageHook{%
  \begin{tikzpicture}[remember picture,overlay]
    \ifthenelse{\thepage = 1}{%
      \node at (current page.center) {\includegraphics{images/template_titel}};
    }{%
      \node at (current page.center) {\includegraphics{images/template_even}};
      \node[font=\bfseries\footnotesize,color=eblue] at ($(current page.north west)+(1.2,-1.2)$) {\thepage};
    }
  \end{tikzpicture}
}

\def\theauthor{}
\renewcommand{\author}[1]{\def\theauthor{#1}}

\AtBeginDocument{%
  \begingroup\color{eblue}
  \vspace*{1.5cm}
  \fontTitleDate{\today\par\vspace{11pt}\relax}
  \fontTitleMain{Bewerbungs\fontTitleMainBf{portfolio}\par\vspace{8pt}\relax}
  \fontTitleName{von \theauthor}
  \endgroup

  %%%
  %%% Include the new TOC entries from the LaTeX run before
  %%% This must be outside the \AtBeginDocument in order that new information
  %%% can be written into the file \jobname.uoc.
  \makeatletter
  \chapter*{Inhalt}
  \IfFileExists{\jobname.uoc}{\input{\jobname.uoc}}%
  \makeatother

  % open file to write new TOC
  \immediate\openout\tuhh@hashFile=\jobname.uoc\relax%
}

\makeatother
\endinput
